summary: the linux kernel (the core of the linux operating system)

# What parts do we want to build?  We must build at least one kernel.
# These are the kernels that are built IF the architecture allows it.

%define buildup 1
%define buildsmp 1
%define buildsource 0
%define buildhugemem 1
%define builddoc 0
%define kabi 1

%define FC2 0
%define FC3 0

# Versions of various parts

#
# Polite request for people who spin their own kernel rpms:
# please modify the "release" field in a way that identifies
# that the kernel isn't the stock distribution kernel, for example by
# adding some text to the end of the version number.
#
%define sublevel 9
%define kversion 2.6.%{sublevel}
%define rpmversion 2.6.%{sublevel}
%define rhbsys  .audit.90
%define release %(R="$Revision: 11 $"; RR="${R##: }"; echo ${RR%%?}).EL%{rhbsys}
%define signmodules 0
%define make_target bzImage

%if %{kabi}
# kABI_major needs to change whenever we make changes that would break
# existing modules.  kABI_minor needs to be bumped whenever we add exports
# (but otherwise maintain the ABI).  When kABI_major gets bumped, reset 
# kABI_minor to 0.
%define kabi_major 4.0
%define kabi_minor 0
%endif

%define KVERREL %{PACKAGE_VERSION}-%{PACKAGE_RELEASE}

# groups of related archs
%define all_x86 i686

# Override generic defaults with per-arch defaults 

%ifarch noarch
%define builddoc 1
%define buildsource 0
%define buildup 0
%define buildsmp 0
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}*.config
%endif

%ifnarch i686
%define buildhugemem 0
%endif

# Second, per-architecture exclusions (ifarch)

%ifarch %{all_x86}
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-i?86*.config
%define image_install_path boot
%define signmodules 1
%endif

%ifarch x86_64
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-x86_64*.config
%define image_install_path boot
%define signmodules 1
%endif

%ifarch ppc64
%define buildsmp 0
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-ppc64*.config
%define image_install_path boot
%define signmodules 1
%define make_target bzImage zImage.stub
%endif

%ifarch ppc64iseries
%define buildsmp 0
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-ppc64*.config
%define image_install_path boot
%define signmodules 1
%define make_target bzImage
%endif

%ifarch s390
%define buildsmp 0
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-s390*.config
%define image_install_path boot
%endif

%ifarch s390x
%define buildsmp 0
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-s390x.config
%define image_install_path boot
%endif

%ifarch ppc
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-ppc*.config
%define buildsmp 0
%define image_install_path boot
%endif

%ifarch ia64
%define all_arch_configs $RPM_SOURCE_DIR/kernel-%{kversion}-ia64.config
%define buildsmp 0
%define image_install_path boot/efi/EFI/redhat
%define signmodules 1
%endif


#
# Three sets of minimum package version requirements in the form of Conflicts:
# to versions below the minimum
#

#
# First the general kernel 2.6 required versions as per
# Documentation/Changes
#
%define kernel_dot_org_conflicts  ppp <= 2.3.15, pcmcia-cs <= 3.1.20, isdn4k-utils <= 3.0, mount < 2.10r-5, nfs-utils < 1.0.3, e2fsprogs < 1.29, util-linux < 2.10, jfsutils < 1.0.14, reiserfsprogs < 3.6.3, xfsprogs < 2.1.0, procps < 2.0.9, oprofile < 0.5.3

# 
# Then a series of requirements that are distribution specific, either 
# because we add patches for something, or the older versions have 
# problems with the newer kernel or lack certain things that make 
# integration in the distro harder than needed.
#
%define package_conflicts  cipe < 1.4.5, tux < 2.1.0, kudzu <= 0.92, initscripts < 7.23, dev < 3.2-7, iptables < 1.2.5-3, bcm5820 < 1.81, nvidia-rh72 <= 1.0, ipw2200-firmware < 2.2

#
# Several packages had bugs in them that became obvious when the NPTL
# threading code got integrated. 
#
%define nptl_conflicts SysVinit < 2.84-13, pam < 0.75-48, vixie-cron < 3.0.1-73, privoxy < 3.0.0-8, spamassassin < 2.44-4.8.x,  cups < 1.1.17-13

#
# Packages that need to be installed before the kernel is, because the %post
# scripts use them.
#
%define kernel_prereq  fileutils, module-init-tools, initscripts >= 5.83, mkinitrd >= 4.1.15

#
# don't use RPM's internal dependency generator, instead
# just use our magic one that finds the versions of kernel modules for
# provides and don't do any requires
# (we used to just turn off AutoReqProv on all packages)
#
%define _use_internal_dependency_generator 0
%define __find_provides /usr/lib/rpm/redhat/find-kmod-provides.sh
%define __find_requires %{nil}

Name: kernel
Group: System Environment/Kernel
License: GPLv2
Version: %{rpmversion}
Release: %{release}
ExclusiveArch: noarch %{all_x86} x86_64 ppc64 ppc64iseries s390 s390x ia64
ExclusiveOS: Linux
Provides: kernel = %{version}
Provides: kernel-drm = 4.3.0
Provides: kernel-%{_target_cpu} = %{rpmversion}-%{release}

%if %{kabi}
Provides: kABI(%{kabi_major}.%{_target_cpu}) = %{kabi_minor}
%endif

Prereq: %{kernel_prereq}
Conflicts: %{kernel_dot_org_conflicts}
Conflicts: %{package_conflicts}
Conflicts: %{nptl_conflicts}
# We can't let RPM do the dependencies automatic because it'll then pick up
# a correct but undesirable perl dependency from the module headers which
# isn't required for the kernel proper to function


#
# List the packages used during the kernel build
#
BuildPreReq: module-init-tools, patch >= 2.5.4, bash >= 2.03, sh-utils, tar
BuildPreReq: bzip2, findutils, gzip, m4, perl, make >= 3.78, gnupg, kernel-utils 
BuildRequires: gcc >= 2.96-98, binutils >= 2.12, redhat-rpm-config >= 8.0.32.1
BuildConflicts: rhbuildsys(DiskFree) < 500Mb



Source0: ftp://ftp.kernel.org/pub/linux/kernel/v2.6/linux-%{kversion}.tar.bz2

Source10: COPYING.modules
Source11: genkey

Source22: kernel-%{kversion}-i686.config
Source23: kernel-%{kversion}-i686-smp.config
Source24: kernel-%{kversion}-i686-hugemem.config
Source25: kernel-%{kversion}-x86_64.config
Source26: kernel-%{kversion}-x86_64-smp.config
Source27: kernel-%{kversion}-ppc64.config
Source28: kernel-%{kversion}-ppc64iseries.config
Source29: kernel-%{kversion}-s390.config
Source30: kernel-%{kversion}-s390x.config
Source34: kernel-%{kversion}-ppc.config
Source35: kernel-%{kversion}-ia64.config

#
# Patches 0 through 100 are meant for core subsystem upgrades
#
Patch3: patch-2.6.9-ac11.bz2
Patch4: linux-2.6.9-selected-ac-bits.patch

#
# Patches 10 to 100 are upstream patches we want to back out 
#
Patch10: linux-2.6.9-ac-backouts.patch
Patch11: linux-2.6.7-iobitmap.patch

# Patches 100 through 500 are meant for architecture patches

# 200 - 299   x86(-64)
Patch200: linux-2.6.5-x86-nostack.patch
Patch201: linux-2.6.9-x86_64-copy_user_generic-exception.patch
Patch202: linux-2.6.9-x86-share-cachedescriptors.patch
Patch203: linux-2.6.9-x86_64-configure-oops-stackdump.patch
Patch204: linux-2.6.9-x86_64-phys_proc_id-only-when-initialised.patch
Patch205: linux-2.6.9-x86_64-missing-compat-ioctls.patch
Patch206: linux-2.6.9-x86-show_trace-irq-context.patch
Patch207: linux-2.6.9-x86_64-lost-edge-triggered-irqs.patch
Patch208: linux-2.6.9-x86_64-mga-dri.patch
Patch209: linux-2.6.9-x86_64-ni_syscall-overrun.patch
Patch210: linux-2.6.9-x86_64-flexmmap.patch
Patch211: linux-2.6.9-x86_64-task_size-32bit.patch
Patch212: linux-2.6.9-x86-sysenter-ebp.patch
Patch213: linux-2.6.10-x86-dma_declare_coherent_memory-kmalloc-args.patch
Patch214: linux-2.6.9-x86-intel-ich7-ids.patch
Patch215: linux-2.6.9-x86_64-hit-hpet-twice.patch
Patch216: linux-2.6.9-x86-vsyscall-sysenter-unwind-info.patch
Patch217: linux-2.6.9-x86_64-switch_to-missinglock.patch
Patch218: linux-2.6.9-x86-enhanced-speedstep.patch
Patch219: linux-2.6.9-x86_64-nmi-switch.patch
Patch220: linux-2.6.9-x86_64-panic_timeout.patch
Patch221: linux-2.6.9-x86_64-srat-numa.patch
Patch222: linux-2.6.9-x86_64-hugetlb.patch
Patch223: linux-2.6.9-x86_64-change_page_attr-flush-fix.patch
Patch224: linux-2.6.9-x86_64-syscall_signal-restart.patch
Patch225: linux-2.6.9-x86_64-clustered-apic.patch
Patch226: linux-2.6.9-x86_64-amd-dualcore.patch

# 300 - 399   ppc(64)
Patch300: linux-2.6.2-ppc64-build.patch
Patch301: linux-2.6.8-ppc64-netboot.patch
Patch302: linux-2.6.9-ppc64-singlestep.patch
Patch303: linux-2.6.9-ppc64-hvsi-udbg.patch
Patch304: linux-2.6.9-ppc64-hvsi-reset.patch
Patch305: linux-2.6.9-ppc64-pci-hostbridge-hotplug.patch
Patch306: linux-2.6.9-ppc64-vscsi.patch
Patch307: linux-2.6.9-ppc64-signal-backtrace.patch
Patch308: linux-2.6.9-ppc64-hvsi-hangup.patch
Patch309: linux-2.6.9-ppc64-cpu-hotplug-map-cpu-node.patch
Patch310: linux-2.6.9-ppc64-cpu-hotplug-sched-domains.patch
Patch311: linux-2.6.9-ppc64-cpu-hotplug-notifier.patch
Patch312: linux-2.6.9-ppc64-cpu-hotplug-reinit-scheddomains.patch
Patch313: linux-2.6.9-ppc64-cpu-hotplug-destroy_sched_domains.patch
Patch314: linux-2.6.9-ppc64-cpu-hotplug-use-notifier.patch
Patch315: linux-2.6.9-ppc64-sigsuspend-regstomping.patch
Patch316: linux-2.6.9-ppc64-icom-driver.patch
Patch317: linux-2.6.9-ppc64-ibmvscsi-race-fix.patch
Patch318: linux-2.6.9-ppc64-ensure-irqs-not-hard-disabled.patch
Patch319: linux-2.6.9-ppc64-purr.patch
Patch320: linux-2.6.9-ppc64-eeh-reset-state2.patch
Patch321: linux-2.6.9-ppc64-tce-table-space.patch
Patch322: linux-2.6.9-ppc64-viocd.patch
Patch323: linux-2.6.9-ppc64-lparcfg-paca-align.patch
Patch324: linux-2.6.9-ppc64-ibmveth-getlink.patch
Patch325: linux-2.6.9-ppc64-rpaclose.patch
Patch326: linux-2.6.9-ppc64-alloc-consistent-order.patch
Patch327: linux-2.6.9-ppc64-sighandler-stackalign.patch
Patch328: linux-2.6.9-ppc64-eeh-recover.patch
Patch329: linux-2.6.9-ppc64-idle-setup.patch
Patch330: linux-2.6.9-ppc64-tiocgicount32.patch
Patch331: linux-2.6.9-ppc64-vpa-init.patch
Patch332: linux-2.6.9-ppc64-prom-init.patch
Patch333: linux-2.6.9-ppc64-getpurr.patch
Patch334: linux-2.6.9-ppc64-xmon-early.patch
Patch335: linux-2.6.9-ppc64-iseries-veth-mod-race.patch
Patch336: linux-2.6.9-ppc64-viocd-2.patch
Patch337: linux-2.6.9-ppc64-ibmveth-starve.patch
Patch338: linux-2.6.9-ppc64-numa-memhole.patch
Patch339: linux-2.6.9-ppc64-numa-setup.patch

# 400 - 499   ia64
Patch400: linux-2.6.3-ia64-build.patch
Patch401: linux-2.6.9-ia64-sn2-update.patch
Patch402: linux-2.6.9-ia64-pci-sn2-fix.patch
Patch403: linux-2.6.9-ia64-mmtimer-sn2-fix.patch
Patch404: linux-2.6.9-ia64-qla1280-sn2-fix.patch
Patch405: linux-2.6.9-ia64-sgiioc4-sn2-fix.patch
Patch406: linux-2.6.9-ia64-sn-console-sn2-fix.patch
Patch407: linux-2.6.9-ia64-snsc-sn2-fix.patch
Patch408: linux-2.6.9-ia64-cyclone-timer-fix.patch
Patch409: linux-2.6.9-ia64-irq-routing-maxcpus.patch
Patch410: linux-2.6.9-ia64-sba_iommu-size.patch
Patch411: linux-2.6.9-ia64-tr_info-hang.patch
Patch412: linux-2.6.9-ia64-cpu-relax.patch
Patch413: linux-2.6.9-ia64-init-trigger-switch4.patch
Patch414: linux-2.6.9-ia64-sgiioc-ide-workaround.patch
Patch415: linux-2.6.9-ia64-rx1600-pdh-console-fix.patch
Patch416: linux-2.6.9-ia64-sys_waitid.patch
Patch417: linux-2.6.9-ia64-zx2-idents.patch
Patch418: linux-2.6.9-ia64-ia32_signal-memset-correctness.patch

# 500 - 599   s390(x)
Patch500: linux-2.6.1-s390-compile.patch
Patch501: linux-2.6.9-s390-autoraid.patch
Patch502: linux-2.6.9-s390-qeth-fake_ll-fix.patch
Patch503: linux-2.6.9-s390-zfcp_port-fix.patch
Patch504: linux-2.6.9-s390-zfcp-stackframe.patch
Patch506: linux-2.6.9-s390-dasd-fixed-buffer.patch
Patch507: linux-2.6.9-s390-core_dump-fix.patch
Patch508: linux-2.6.9-s390-lcs_startup-fix.patch
Patch509: linux-2.6.9-s390-qeth_addr-fix.patch
Patch510: linux-2.6.9-s390-qeth_hipersocket-fix.patch
Patch511: linux-2.6.9-s390-no_hz_timer-fix.patch
Patch512: linux-2.6.9-s390-config_watchdog.patch
Patch513: linux-2.6.9-s390-lcs_seq_numbers.patch
Patch514: linux-2.6.11-s390-qeth_fake_ll-fix.patch
Patch515: linux-2.6.10-s390-dasd_io_error-fix.patch
Patch516: linux-2.6.10-s390-qdio_packet_loss-fix.patch
Patch517: linux-2.6.10-s390-cio-fix.patch
Patch518: linux-2.6.11-s390-cio-vary_off-fix.patch
Patch519: linux-2.6.10-s390-qdio_time_delay-fix.patch

#
# Patches 900 through 1000 are reserved for bugfixes to the core system
# and patches related to how RPMs are build
#
Patch900: linux-2.4.0-nonintconfig.patch

Patch910: linux-2.6.0-exec-shield.patch
Patch911: linux-2.6.8-print-fatal-signals.patch
Patch912: linux-2.6.8-execshield-vaspace.patch

Patch920: linux-2.6.8-4g4g-backout.patch
Patch921: linux-2.6.0-4g4g.patch
Patch922: linux-2.6.9-4g4g-noncachable.patch
Patch923: linux-2.6.9-4g4g-hugemem-warning.patch
Patch924: linux-2.6.9-4g4g-maxtasksize.patch
Patch930: linux-2.6.0-must_check.patch
Patch940: linux-2.6.2-tux.patch
# Module signing infrastructure.
Patch950: linux-2.6.7-modsign-core.patch
Patch951: linux-2.6.7-modsign-crypto.patch
Patch952: linux-2.6.7-modsign-ksign.patch
Patch953: linux-2.6.7-modsign-mpilib.patch
Patch954: linux-2.6.7-modsign-script.patch
Patch955: linux-2.6.7-modsign-include.patch
Patch956: linux-2.6.9-sha1.patch

#
# Patches 1000 to 4999 are reserved for bugfixes to drivers and filesystems
#
Patch1000: linux-2.4.0-test11-vidfail.patch
Patch1020: linux-2.6.4-stackusage.patch
# Ext2/Ext3 bits.
Patch1030: linux-2.6.5-ext3-reservations.patch
Patch1031: linux-2.6.8-ext3-reservations-update.patch
Patch1032: linux-2.6.9-ext3-cleanup-abort.patch
Patch1033: linux-2.6.5-ext3-online-resize.patch
Patch1034: linux-2.6.9-ext3-handle-bitmapdel.patch
Patch1035: linux-2.6.9-ext3-handle-double-revoke.patch
Patch1036: linux-2.6.9-ext2-mbcache.patch
Patch1037: linux-2.6.9-ext3-mbcache.patch
Patch1038: linux-2.6.9-ext3-umount-leak.patch
Patch1039: linux-2.6.9-ext3-file-limit.patch
Patch1040: linux-2.6.9-ext3-release-race.patch

Patch1050: linux-2.6.7-devmem.patch
Patch1051: linux-2.6.0-devmem.patch
Patch1060: linux-2.6.3-crash-driver.patch
Patch1070: linux-2.6.0-sleepon.patch
Patch1080: linux-2.6.7-voluntary-preemption.patch
Patch1081: linux-2.6.7-early-schedule.patch

# SATA bits.
Patch1100: linux-2.6.9-sata.patch
Patch1101: linux-2.6.9-sata-nth-page.patch
Patch1102: linux-2.6.9-sata-ahci-update.patch
Patch1103: linux-2.6.9-sata-updates.patch
Patch1104: linux-2.6.10-sata-updates.patch
Patch1105: linux-2.6.9-sata-lba48-max-sectors.patch

# SCSI bits.
Patch1120: linux-2.6.7-scsi-whitelist.patch
Patch1121: linux-2.6.9-scsi-bounce-limit.patch
Patch1122: linux-2.6.9-scsi-aic-hostraid.patch
Patch1123: linux-2.6.10-scsi-midlayer-updates.patch
Patch1124: linux-2.6.9-scsi-aic-oops-nohardware.patch
Patch1125: linux-2.6.9-scsi-reset-ULDs.patch
Patch1126: linux-2.6.9-scsi-ips-update.patch
Patch1127: linux-2.6.9-scsi-NULL-iterate-devices.patch
Patch1128: linux-2.6.10-scsi-qla2xxx-update.patch
Patch1129: linux-2.6.10-scsi-cciss-clustering-fix.patch
Patch1130: linux-2.6.9-scsi-usb-forced-remove-oops.patch
Patch1131: linux-2.6.9-scsi-test_unit_ready-cdrom.patch
Patch1132: linux-2.6.9-scsi-aic-leakplug.patch
Patch1133: linux-2.6.9-scsi-refcount-cmd-allocation.patch
Patch1134: linux-2.6.9-scsi-full-status-sg_io.patch
Patch1135: linux-2.6.9-scsi-sg_cmd_done-sg_release-race.patch
Patch1136: linux-2.6.9-scsi-aac-remove-handle-aif.patch
Patch1137: linux-2.6.9-scsi-megaraid-kioc.patch
Patch1138: linux-2.6.9-scsi-inverted-refcounting.patch
Patch1139: linux-2.6.9-scsi-ioctl-overflow.patch

Patch1140: linux-2.6.9-blockfixes.patch
Patch1141: linux-2.6.9-block-segment-coalesce.patch
Patch1142: linux-2.6.9-cciss-getluninfo-fix.patch
Patch1143: linux-2.6.9-sx8-sysfs.patch
Patch1144: linux-2.6.9-block-blkdev_get_blocks-EOF.patch
Patch1145: linux-2.6.9-block-cciss-ioctl-returncode.patch
Patch1146: linux-2.6.9-block-cciss-id-updates.patch
Patch1147: linux-2.6.9-block-__getblk_slow-hang.patch

Patch1150: linux-2.6.9-md-resync-bugs.patch
Patch1151: linux-2.6.9-md-nr_pending.patch
Patch1152: linux-2.6.9-dm-dm_target_msg-ioctl.patch
Patch1153: linux-2.6.9-dm-multipath-ioctl-ref-by-devno.patch
Patch1154: linux-2.6.9-dm-fix-mirror-log-refcount.patch
Patch1155: linux-2.6.9-dm-suspendhook.patch
Patch1156: linux-2.6.9-dm-raid1-deadlock-fix.patch
Patch1157: linux-2.6.9-dm-kprintf-tidy.patch
Patch1158: linux-2.6.9-dm-add-dm_dev-name.patch
Patch1159: linux-2.6.9-dm-details-recordrestore.patch
Patch1160: linux-2.6.9-dm-export-mapinfo.patch
Patch1161: linux-2.6.9-dm-multipath.patch
Patch1162: linux-2.6.9-dm-64bit-fixes.patch
Patch1163: linux-2.6.9-dm-multipath-suspend-requeueing.patch
Patch1164: linux-2.6.9-dm-avoid-bdget.patch
Patch1165: linux-2.6.9-md-bi_max_vecs-fix.patch
Patch1166: linux-2.6.9-md-multipath-assemly.patch

# NFS bits.
Patch1200: linux-2.6.9-NFS-mounthangfix.patch
Patch1201: linux-2.6.9-NFSD-non-null-getxattr.patch
Patch1202: linux-2.6.9-NFSD-locallock-oopsfix.patch
Patch1203: linux-2.6.9-NFSD-putrootfh-return.patch
Patch1204: linux-2.6.9-NFSD-portwarning-dottedquads.patch
Patch1205: linux-2.6.9-NFS-cthon-rename.patch
Patch1206: linux-2.6.8-lockd-racewarn2.patch
Patch1207: linux-2.6.9-lockd-NLM-length.patch
Patch1208: linux-2.6.9-lockd-block-nosleep.patch
Patch1209: linux-2.6.9-lockd-reclaims.patch
Patch1210: linux-2.6.9-lockd-svc-reclaims.patch
Patch1211: linux-2.6.9-NFS-nlmcreds.patch
Patch1212: linux-2.6.9-rpc-autherr-retry.patch
Patch1213: linux-2.6.9-NFS-stackoverflow.patch
Patch1214: linux-2.6.9-NFSD-add_set_client.patch
Patch1215: linux-2.6.9-NFSD-use_set_client4.patch
Patch1216: linux-2.6.9-lockd-callbacks.patch
Patch1217: linux-2.6.9-NFS-auth-oops.patch
Patch1218: linux-2.6.9-NFS-mmap-corruption.patch
Patch1219: linux-2.6.9-NFS-locking-oops.patch

# Core networking fixes.
Patch1300: linux-2.6.9-net-ipv6-fix-mtu-calculation.patch
Patch1301: linux-2.6.9-net-vlan-change_mtu-success.patch
Patch1302: linux-2.6.9-net-SIOCGIFHWADDR-NULL-dev_addr.patch
Patch1303: linux-2.6.9-net-compat-missing-security.patch
Patch1304: linux-2.6.9-net-xfrm-fixes.patch
Patch1305: linux-2.6.9-net-cmsg_signedness.patch
Patch1306: linux-2.6.9-net-ftp_conntrack_leak.patch
Patch1307: linux-2.6.9-net-ip_options_leak.patch
Patch1308: linux-2.6.9-net-procroute-stale-pointer.patch
Patch1309: linux-2.6.9-net-bonding-panic.patch
Patch1310: linux-2.6.9-net-sk_forward_alloc-BUG.patch
Patch1311: linux-2.6.9-net-tcp-bic-fix.patch
Patch1312: linux-2.6.9-net-fragment-corruption.patch
Patch1313: linux-2.6.9-net-sctp-recv-accounting.patch
Patch1314: linux-2.6.9-net-ipsec-sa-sequence-collision.patch
Patch1315: linux-2.6.9-net-sctp-sendbuffer-accounting.patch

# NIC driver updates
Patch1350: linux-2.6.9-net-b44-4g4g.patch
Patch1351: linux-2.6.9-net-tr-irqlock-fix.patch
Patch1352: linux-2.6.9-net-tulip-waitdmastop.patch
Patch1353: linux-2.6.10-net-3c59x-reload-EEPROM.patch
Patch1354: linux-2.6.9-net-tg3-fiber-autoneg-bounces.patch
Patch1355: linux-2.6.9-net-e100-xmit-timeout-enable-interrupts.patch
Patch1356: linux-2.6.9-net-forcedeth-rx-csum.patch
Patch1357: linux-2.6.9-net-via-rhine-devinit.patch
Patch1358: linux-2.6.9-net-e1000-erratum23.patch
Patch1359: linux-2.6.9-net-e1000-post-mature-writeback.patch
Patch1360: linux-2.6.9-net-e1000-rx-mini-jumbo-inval.patch
Patch1361: linux-2.6.9-net-e1000-64k-align-check-dma.patch
Patch1362: linux-2.6.9-net-s2io-update.patch
Patch1364: linux-2.6.10-net-e1000-update.patch
Patch1365: linux-2.6.10-net-e100-update.patch
Patch1366: linux-2.6.9-net-e100-e100_tx_timeout-workqueue.patch
Patch1367: linux-2.6.9-net-sk98lin-module_device_table.patch
Patch1368: linux-2.6.10-net-tg3-update.patch
Patch1369: linux-2.6.9-net-e100-fix-NAPI-state-machine.patch
Patch1370: linux-2.6.9-net-e100-ich7.patch
Patch1371: linux-2.6.9-net-e1000-avoid-sleep-in-timer-context.patch
Patch1372: linux-2.6.9-net-e1000-flush-rmmod.patch
Patch1373: linux-2.6.9-net-forcedeth-class-quirk.patch

# ACPI Horrors.
Patch1400: linux-2.6.9-acpi-breakpoint-nop.patch
Patch1401: linux-2.6.9-acpi-lequal-less-strict.patch
Patch1402: linux-2.6.9-acpi-debug-level.patch
Patch1403: linux-2.6.9-acpi-reset-mechanism.patch

# Netdump bits.
Patch1500: linux-2.6.8-crashdump-common.patch
Patch1501: linux-2.6.9-crashdump-fix-reboot-failure.patch
Patch1510: linux-2.6.7-netdump.patch
Patch1520: linux-2.6.8-netconsole.patch
Patch1521: linux-2.6.9-netconsole-tg3-oops.patch
Patch1530: linux-2.6.9-netpoll-oops.patch

# Diskdump goodies.
Patch1540: linux-2.6.8-diskdump-3.patch
Patch1541: linux-2.6.8-diskdump-scsi-3.patch
Patch1542: linux-2.6.8-mptfusion-diskdump.patch
Patch1543: linux-2.6.7-aic7xxx-diskdump.patch
Patch1544: linux-2.6.8-sym53c8xx-diskdump.patch
Patch1545: linux-2.6.8-ipr-diskdump.patch
Patch1546: linux-2.6.9-diskdump-dienmi.patch
Patch1547: linux-2.6.9-diskdump-export_state.patch
Patch1548: linux-2.6.9-diskdump-mdelay.patch
Patch1549: linux-2.6.9-diskdump-mem.patch
Patch1550: linux-2.6.9-diskdump-system_state.patch
Patch1551: linux-2.6.9-diskdump-condition.patch
Patch1552: linux-2.6.9-diskdump-gendisk.patch
Patch1553: linux-2.6.9-diskdump-sata.patch
Patch1554: linux-2.6.9-diskdump-megaraid.patch
Patch1555: linux-2.6.9-diskdump-wce.patch
Patch1556: linux-2.6.9-diskdump-badmsg.patch
Patch1557: linux-2.6.9-dump_smp_call-ia64.patch
Patch1558: linux-2.6.9-dump_smp_call-i386.patch
Patch1559: linux-2.6.9-dump_smp_call-ppc64.patch
Patch1560: linux-2.6.9-dump_smp_call-x86_64.patch
Patch1561: linux-2.6.9-dump_smp_call_function-3.patch

# SELinux bits
Patch1600: linux-2.6.9-selinux-netif-fixes.patch
Patch1601: linux-2.6.9-selinux-setxattr-daccheck.patch
Patch1602: linux-2.6.9-selinux-sidtab-locking-fix.patch
Patch1603: linux-2.6.9-selinux-mediate-send_sigurg.patch
Patch1604: linux-2.6.9-selinux-setscheduler-deadlock.patch
Patch1605: linux-2.6.9-selinux-avc-rcu.patch
Patch1606: linux-2.6.9-selinux-xattr-rework-tmpfs-mm.patch
Patch1608: linux-2.6.9-selinux-destroy-avtab-node-cache.patch
Patch1609: linux-2.6.9-selinux-avc_update_node-spinlock-oops.patch
Patch1610: linux-2.6.9-selinux-avc-deadlock.patch

# Misc bits.
Patch1700: linux-2.6.9-procfs-getpid-fix.patch
Patch1701: linux-2.6.9-procfs-deadtask-dereference.patch
Patch1710: linux-2.6.9-edd-config.patch
Patch1720: linux-2.6.10-sysfs-update.patch
Patch1730: linux-2.6.9-signal-handling-dr7.patch
Patch1740: linux-2.6.9-timer-barrier.patch
Patch1750: linux-2.6.9-nonpower2sectorsize.patch
Patch1760: linux-2.6.9-module_version.patch
Patch1780: linux-2.6.9-irqaffinity-disable-E7xxx.patch
Patch1781: linux-2.6.9-ASPM-workaround-PCIE.patch
Patch1782: linux-2.6.9-hotplug-msi-update.patch
Patch1783: linux-2.6.9-80332-IOP-hotplug.patch
Patch1784: linux-2.6.9-ExpressCard-hotplug-ICH6M.patch
Patch1785: linux-2.6.9-pcix-hotplug-fixes.patch
Patch1790: linux-2.6.9-hugetlb_get_unmapped_area-fix.patch 
Patch1800: linux-2.6.9-statm-combined.patch
Patch1810: linux-2.6.9-idefloppy-suppress-noise.patch
Patch1820: linux-2.6.9-do_wait-hang-fix.patch
Patch1830: linux-2.6.9-pci_mmcfg_write-flush_error.patch
Patch1840: linux-2.6.9-via-apic-quirk-devinit.patch
Patch1850: linux-2.6.9-autofs-recognise-map-update.patch
Patch1860: linux-2.6.9-taint-mce.patch
Patch1861: linux-2.6.9-taint-force-rmmod.patch
Patch1862: linux-2.6.9-taint-badpage.patch
Patch1870: linux-2.6.9-xtime-correctness.patch
Patch1880: linux-2.6.9-pagevec-alignment.patch
Patch1890: linux-2.6.9-overlapping-vma.patch
Patch1900: linux-2.6.9-futex-disable-warning.patch
Patch1901: linux-2.6.9-futex-mmap_sem-deadlock.patch
Patch1910: linux-2.6.9-spinlock-debug-panic.patch
Patch1920: linux-2.6.9-compat-F_GETLK.patch
Patch1930: linux-2.6.9-waitid-bogus-ECHILD.patch
Patch1950: linux-2.6.9-agp-missing-cacheflushes.patch
Patch1951: linux-2.6.9-agp-posting-bugs.patch
Patch1960: linux-2.6.9-vc-resizing-overflow.patch
Patch1970: linux-2.6.9-kern_exit-race.patch
Patch1971: linux-2.6.9-exit-deadtask-nodentry-cache.patch
Patch1990: linux-2.6.9-random-sysctl-overflow.patch

# VM bits.
Patch2000: linux-2.6.9-vm-tame-oomkiller.patch
Patch2001: linux-2.6.9-vm-dirty_ratio-initialisation-fix.patch
Patch2002: linux-2.6.9-vm-pageout-throttling.patch
Patch2003: linux-2.6.9-vm-page-writeback.patch
Patch2004: linux-2.6.9-vm-sc-congested.patch
Patch2005: linux-2.6.9-vm-total-scanned.patch
Patch2007: linux-2.6.9-rlimit_memlock-bypass.patch
Patch2009: linux-2.6.9-vm-oomkiller-tweak.patch
Patch2010: linux-2.6.9-vm-oomkiller-debugging.patch
Patch2011: linux-2.6.9-invalidate-page-race-fix.patch
Patch2012: linux-2.6.9-vm-mincore.patch
Patch2013: linux-2.6.9-vm-dma-zone-exhaustion.patch
Patch2014: linux-2.6.9-vm-improve-scanning.patch
Patch2015: linux-2.6.9-vm-swaptoken-null-mm.patch

# IDE bits.
Patch2100: linux-2.6.9-ide-csb6-raid.patch
Patch2101: linux-2.6.9-ide-cd-early-EOF.patch
Patch2102: linux-2.6.9-ide-cd-panic.patch
Patch2103: linux-2.6.9-ide-supress-error-msg.patch
Patch2104: linux-2.6.9-ide-blacklist-update.patch

# USB bits
Patch2200: linux-2.6.9-usb-edgeport-overflows.patch
Patch2201: linux-2.6.9-usb-storage-reload.patch

# More SCSI bits.
Patch2300: linux-2.6.9-scsi-silence-sg_io-warning.patch
Patch2301: linux-2.6.9-scsi-qla-fix-hw-segment-counting.patch
Patch2302: linux-2.6.9-scsi-aacraid-dead-param.patch
Patch2303: linux-2.6.9-scsi-megaraid-update.patch
Patch2304: linux-2.6.9-scsi-megaraid-warning-fixes.patch

Patch2999: linux-2.6.3-printopen.patch

#
# External drivers that are about to get accepted upstream
#

# Emulex FC driver
Patch3000: linux-2.6.9-emulex-lpfc.patch
Patch3001: linux-2.6.9-emulex-lpfc-80163.patch
Patch3002: linux-2.6.9-emulex-lpfc-80166.patch
Patch3003: linux-2.6.9-emulex-lpfc-80166x2.patch

# Speedtouch USB DSL modem driver.
Patch3010: linux-2.6.9-speedtouch.patch

# Intel Centrino wireless drivers.
Patch3020: linux-2.6.9-ipw2100.patch
Patch3021: linux-2.6.9-ipw2200.patch
Patch3022: linux-2.6.9-ieee80211.patch
Patch3023: linux-2.6.9-80211-update.patch
Patch3024: linux-2.6.9-ipw2100-update.patch
Patch3025: linux-2.6.9-ipw2200-update.patch

# Misc bits.
Patch4001: linux-2.6.10-ac-selected-bits.patch
Patch4002: linux-2.6.9-pty-smp-race.patch
Patch4003: linux-2.6.9-intel8x0-sound-ids.patch
Patch4004: linux-2.6.9-x86-sysrq-b-oops.patch
Patch4005: linux-2.6.9-sys_io_setup-unwritable-addr.patch
Patch4006: linux-2.6.9-ptrace-fixes.patch
Patch4007: linux-2.6.9-panic_on_oops-default.patch
Patch4008: linux-2.6.11-sys_ipc-fix.patch
Patch4009: linux-2.6.9-alsa-intel-hd-driver.patch
Patch4010: linux-2.6.9-gpt-partition-noprobe.patch
Patch4013: linux-2.6.9-tmpfs-truncate-BUG.patch
Patch4014: linux-2.6.9-cpufreq-silence-warnings.patch
Patch4015: linux-2.6.9-vesafb-probe-error.patch
Patch4016: linux-2.6.9-dellserial.patch
Patch4017: linux-2.6.9-autofs-leak.patch
Patch4018: linux-2.6.9-tty-locking-fix.patch
Patch4019: linux-2.6.9-execshield-iret.patch

# Security fixes.
Patch5000: linux-2.6.9-CAN-2004-1056-drm-insufficient-locking.patch
Patch5001: linux-2.6.9-CAN-2004-1137-igmp-flaws.patch
Patch5002: linux-2.6.9-CAN-2004-1235-do_brk.patch
Patch5003: linux-2.6.9-CAN-2005-0001-expand-stack-race.patch
Patch5004: linux-2.6.9-CAN-2005-0135-ia64-unwind.patch
Patch5005: linux-2.6.9-CAN-2005-0136-ia64-ptrace.patch
Patch5006: linux-2.6.9-CAN-2005-0176-shmlockperms.patch
Patch5007: linux-2.6.9-CAN-2005-0204-outs-iobitmap.patch
Patch5008: linux-2.6.9-CAN-2005-0207-NFSD-O_DIRECT.patch
Patch5009: linux-2.6.9-CAN-2005-0209-dst-leak.patch
Patch5010: linux-2.6.9-CAN-2005-0384-ppp-dos.patch
Patch5011: linux-2.6.9-CAN-2005-0400-ext2-infoleak.patch
Patch5012: linux-2.6.9-CAN-2005-0449-ip_defrag.patch
Patch5013: linux-2.6.9-CAN-2005-0531-size_t.patch
Patch5014: linux-2.6.9-CAN-2005-0736-epoll-overflow.patch
Patch5015: linux-2.6.9-CAN-2005-0749-elfloader-kfree.patch
Patch5016: linux-2.6.9-CAN-2005-0750-bluetooth-rangecheck.patch
Patch5017: linux-2.6.9-CAN-2005-0767-drm-radeon-race.patch
Patch5018: linux-2.6.9-CAN-2005-0815-isofs.patch
Patch5019: linux-2.6.9-CAN-2005-0839-N_MOUSE.patch
Patch5020: linux-2.6.10-CAN-2005-0867-sysfs-signedness.patch
Patch5021: linux-2.6.9-CAN-2005-1263-binfmt_elf.patch
Patch5022: linux-2.6.9-CAN-2005-1264-raw-blkdev_ioctl.patch
Patch5023: linux-2.6.9-CAN-2005-2709-sysctl.patch

# Security fixes that don't have CANs assigned (yet?)
# These get renamed if one is later assigned.
Patch5100: linux-2.6.9-ptrace-sched-race.patch

#
# 10000 to 20000 is for stuff that has to come last due to the
# amount of drivers they touch. But only these should go here. 
# Not patches you're too lazy for to put in the proper place.
#

Patch10000: linux-2.6.0-compile.patch
Patch10001: linux-2.6.9-exports.patch

# Audit patches
# First, those which are already upstream....
Patch20000: linux-2.6.9-audit-retcode.patch
Patch20001: linux-2.6.9-audit-caps.patch
Patch20002: linux-2.6.9-auditcongestion.patch
Patch20003: linux-2.6.9-auditlost.patch
Patch20004: linux-2.6.9-audit-loginuid-proc.patch
Patch20005: linux-2.6.9-ppc64-auditsyscall.patch
Patch20006: linux-2.6.9-auditinonum.patch
Patch20007: linux-2.6.9-audit-netlinkfix.patch
Patch20008: linux-2.6.9-auditdev.patch
Patch20009: linux-2.6.9-auditipc.patch
Patch20010: linux-2.6.9-auditstr.patch
Patch20011: linux-2.6.9-auditaltroot.patch
Patch20012: linux-2.6.9-auditarch.patch
Patch20013: linux-2.6.11-rc3.stamp.patch
Patch20014: linux-2.6.9-auditoneliners.patch
Patch20015: linux-2.6.9-ia64-audit-syscall.patch
Patch20016: linux-2.6.9-audit-comm-exe.patch
Patch20017: linux-2.6.9-audit-netlink-loginuid.patch
Patch20018: linux-2.6.9-audit-netlink-perms.patch
Patch20019: linux-2.6.9-auditrequeue.patch
Patch20020: linux-2.6.9-audit-fix-setluid.patch
Patch20021: linux-2.6.9-audit-reuse-skb.patch
Patch20022: linux-2.6.9-audit-x86_64-compat.patch
Patch20024: linux-2.6.9-audit-sel-setscheduler.patch
Patch20025: linux-2.6.9-audit-unknownperm.patch
Patch20026: linux-2.6.9-audit-signal.patch
Patch20027: linux-2.6.9-audit-to-skb-1.patch
Patch20028: linux-2.6.9-audit-to-skb-2.patch
Patch20029: linux-2.6.9-audit-to-skb-3.patch
Patch20030: linux-2.6.9-audit-va-abuse.patch
Patch20031: linux-2.6.9-avc-deadlock.patch
Patch20032: linux-2.6.9-audit-types.patch
Patch20033: linux-2.6.9-audit-spelling.patch
Patch20034: linux-2.6.9-audit-socketcalls.patch
Patch20035: linux-2.6.9-audit-untrusted.patch
Patch20036: linux-2.6.9-audit-kthread.patch
Patch20037: linux-2.6.9-audit-not-auditd.patch
Patch20038: linux-2.6.9-avc-path.patch
Patch20040: linux-2.6.9-auid.patch
Patch20041: linux-2.6.9-audit-serial.patch
Patch20042: linux-2.6.9-audit-arch-first.patch
Patch20043: linux-2.6.9-audit-untrusted-2.patch
Patch20044: linux-2.6.9-audit-aux-defer-free.patch
Patch20045: linux-2.6.9-audit-pwd.patch
Patch20046: linux-2.6.9-netlink-hash.patch
Patch20047: linux-2.6.9-audit-filters.patch
Patch20048: linux-2.6.9-audit-inode-flags.patch
Patch20049: linux-2.6.9-audit-reply-thread.patch
Patch20050: linux-2.6.9-audit-backlog-wait.patch
Patch20051: linux-2.6.9-audit-loglevel.patch
Patch20052: linux-2.6.9-audit-stop-waiting.patch
Patch20053: linux-2.6.9-audit-not-auditd-me-harder.patch
Patch20054: linux-2.6.9-audit-free-atomic.patch
Patch20055: linux-2.6.9-audit-serial-sanify.patch
Patch20056: linux-2.6.9-audit-defer-serial.patch
Patch20057: linux-2.6.9-audit-speedup.patch
Patch20058: linux-2.6.9-audit-task-refcnt.patch
Patch20059: linux-2.6.9-audit-dup-rules.patch
Patch20060: linux-2.6.9-audit-ppc64-syscallresult.patch
Patch20061: linux-2.6.9-audit-success-failure.patch
Patch20062: linux-2.6.12-ppc64-audit-sigsuspend.patch
Patch20063: linux-2.6.9-CAN-2005-3181-names_cache.patch

# Then the ones in audit-2.6-mm which are pending...


# ... then the new stuff...
Patch20070: linux-2.6.9-auditfs.patch
Patch20071: linux-2.6.9-auditfs-lock-contention.patch
Patch20072: linux-2.6.9-auditfs-enomem-panic.patch
Patch20073: linux-2.6.9-auditfs-no-watches.patch

# ... and the RHEL-only minor (ABI-preserving) cleanup for fs.h
Patch20080: linux-2.6.9-no-audit_h-in-fs_h.patch
# RHEL-only hack to avoid OOM kill for auditd.
Patch20081: linux-2.6.9-audit-oom-auditd.patch
# Fix module unload race
Patch20082: linux-2.6.9-rmmod-nonblock.patch

# And let's also make the serial console on my i686 box work
Patch20083: linux-2.6.9-ns16550-sercons.patch
# ... and the module signing not die
Patch20084: linux-2.6.9-modsigning-oops.patch
# Extra (post-U1) security fixes
Patch20100: linux-2.6.9-msg_control.patch
Patch20101: linux-2.6.9-can-2005-2492.patch
Patch20102: linux-2.6.9-net-ipv6-exthdrs-bug.patch
Patch20103: linux-2.6.12-network.patch
Patch20104: linux-2.6.12-CAN-2005-1761-ia64-ptrace.patch
Patch20105: linux-2.6.9-CAN-2005-0756-x8664-ptrace-check-segment.patch
Patch20106: linux-2.6.9-CAN-2005-1765-x8664-ptrace-overflow.patch
Patch20107: linux-2.6.9-CAN-2005-2555-cap-net-admin.patch


# END OF PATCH DEFINITIONS

BuildRoot: %{_tmppath}/kernel-%{KVERREL}-root

%description 
The kernel package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system:  memory allocation, process allocation, device
input and output, etc.

%package devel
Summary: Development package for building kernel modules to match the kernel.
Group: System Environment/Kernel
AutoReqProv: no
Provides: kernel-devel-%{_target_cpu} = %{rpmversion}-%{release}

%description devel
This package provides kernel headers and makefiles sufficient to build modules
against the kernel package.

%package sourcecode
Summary: The source code for the Linux kernel.
Group: Development/System
Prereq: fileutils
Requires: make >= 3.78
Requires: gcc >= 3.2
Requires: /usr/bin/strip
# for xconfig and gconfig
Requires: qt-devel, gtk2-devel readline-devel ncurses-devel
Provides: kernel-source
Obsoletes: kernel-source <= 2.6.6

%description sourcecode
The kernel-sourcecode package contains the source code files for the Linux
kernel. The source files can be used to build a custom kernel that is
smaller by virtue of only including drivers for your particular hardware, if
you are so inclined (and you know what you're doing). The customisation
guide in the documentation describes in detail how to do this. This package
is neither needed nor usable for building external kernel modules for
linking such modules into the default operating system kernels.

%package doc
Summary: Various documentation bits found in the kernel source.
Group: Documentation
%if !%{buildsource}
Obsoletes: kernel-source <= 2.6.6
Obsoletes: kernel-sourcecode <= 2.6.6
%endif

%description doc
This package contains documentation files from the kernel
source. Various bits of information about the Linux kernel and the
device drivers shipped with it are documented in these files. 

You'll want to install this package if you need a reference to the
options that can be passed to Linux kernel modules at load time.


%package smp
Summary: The Linux kernel compiled for SMP machines.

Group: System Environment/Kernel
Provides: kernel = %{version}
Provides: kernel-drm = 4.3.0
Prereq: %{kernel_prereq}
Conflicts: %{kernel_dot_org_conflicts}
Conflicts: %{package_conflicts}
Conflicts: %{nptl_conflicts}
# upto and including kernel 2.4.9 rpms, the 4Gb+ kernel was called kernel-enterprise
# now that the smp kernel offers this capability, obsolete the old kernel
Obsoletes: kernel-enterprise < 2.4.10
# We can't let RPM do the dependencies automatic because it'll then pick up
# a correct but undesirable perl dependency from the module headers which
# isn't required for the kernel proper to function

Provides: kernel-smp-%{_target_cpu} = %{rpmversion}-%{release}
%if %{kabi}
Provides: kABI(%{kabi_major}smp.%{_target_cpu}) = %{kabi_minor}
%endif

%description smp
This package includes a SMP version of the Linux kernel. It is
required only on machines with two or more CPUs as well as machines with
hyperthreading technology.

Install the kernel-smp package if your machine uses two or more CPUs.

%package smp-devel
Summary: Development package for building kernel modules to match the SMP kernel.
Group: System Environment/Kernel
Provides: kernel-smp-devel-%{_target_cpu} = %{rpmversion}-%{release}
AutoReqProv: no

%description smp-devel
This package provides kernel headers and makefiles sufficient to build modules
against the SMP kernel package.

%package hugemem
Summary: The Linux kernel compiled for machines with 16 Gigabytes of memory or more.
Group: System Environment/Kernel
Provides: kernel = %{version}
Provides: kernel-drm = 4.3.0
Prereq: %{kernel_prereq}
Conflicts: %{kernel_dot_org_conflicts}
Conflicts: %{package_conflicts}
Conflicts: %{nptl_conflicts}
Obsoletes: kernel-enterprise < 2.4.10
# We can't let RPM do the dependencies automatic because it'll then pick up
# a correct but undesirable perl dependency from the module headers which
# isn't required for the kernel proper to function

Provides: kernel-hugemem-%{_target_cpu} = %{rpmversion}-%{release}
%if %{kabi}
Provides: kABI(%{kabi_major}hugemem.%{_target_cpu}) = %{kabi_minor}
%endif

%description hugemem
This package includes an SMP version of the Linux kernel which
supports systems with 16 Gigabytes of memory or more.

%package hugemem-devel
Summary: Development package for building kernel modules to match the hugemem kernel.
Group: System Environment/Kernel
Provides: kernel-hugemem-devel-%{_target_cpu} = %{rpmversion}-%{release}
AutoReqProv: no

%description hugemem-devel
This package provides kernel headers and makefiles sufficient to build modules
against the hugemem kernel package.

%prep

%setup -q -n %{name}-%{version} -c
cd linux-%{kversion}

#
# Patches 0 through 100 are meant for core subsystem upgrades
# 

# Various fixes from Alan's -ac tree.
%patch3 -p1
%patch4 -p1

#
# Patches to back out
#

# -AC bits we don't want.
%patch10 -p1 -R
# iobitmap increase that breaks booting
%patch11 -p1 -R

#
# Architecture patches
#

#
# x86(-64)
#
%patch200 -p1
# fix x86_64 copy_user_generic
%patch201 -p1
# Share cache descriptors between x86/x86-64
%patch202 -p1
# x86_64: add an option to configure oops stack dump
%patch203 -p1
# x86[64]: display phys_proc_id only when it is initialized
%patch204 -p1
# x86_64: no TIOCSBRK/TIOCCBRK in ia32 emulation
%patch205 -p1
# Fix show_trace() in irq context with CONFIG_4KSTACKS
%patch206 -p1
# x86_64: Fix lost edge triggered irqs on UP kernel
%patch207 -p1
# x86_64: Reenable MGA DRI
%patch208 -p1
# Fix Buffer overrun in arch/x86_64/sys_ia32.c:sys32_ni_syscall()
%patch209 -p1
# Flexible mmap patch for x86-64 
%patch210 -p1
# Fix wrong TASK_SIZE on x86_64 for 32bit processes
%patch211 -p1
# Clear ebp on sysenter return.
%patch212 -p1
# Fix up wrong argument order in dma_declare_coherent_memory()
%patch213 -p1
# ICH7 ID additions
%patch214 -p1
# HPET init needs register to be whacked twice.
%patch215 -p1
# fix i386 vsyscall-sysenter unwind info
%patch216 -p1
# missing lock in switch_to()
%patch217 -p1
# Intel enhanced speedstep fixes.
%patch218 -p1
# NMI switch support for x86_64
%patch219 -p1
# Fix panic() w/panic_timeout hangs instead of rebooting
%patch220 -p1
# SRAT NUMA support.
%patch221 -p1
# Fix hugepages for x86_64
%patch222 -p1
# Fix flush of multiple pages in change_page_attr
%patch223 -p1
# fix syscall/signal restart bug
%patch224 -p1
# Clustered APIC support for x86-64.
%patch225 -p1
# Dual core support for AMD64.
%patch226 -p1

# 
# ppc64
#

# Patch for Kconfig and Makefile build issues
%patch300 -p1
%patch301 -p1
# Fix single stepping on PPC64
%patch302 -p1
# HVSI udbg support
%patch303 -p1
# Make HVSI console survive FSP reset
%patch304 -p1
# Make PCI hostbridge hotplugging work
%patch305 -p1
# Fix IBM VSCSI problems
%patch306 -p1
# Store correct backtracking info in ppc64 signal frames
%patch307 -p1
# Prevent HVSI from oopsing on hangup
%patch308 -p1
# Make ppc64 NUMA map CPU->node before bringing up the CPU
%patch309 -p1
# sched domains / cpu hotplug cleanup
%patch310 -p1
# Add a CPU_DOWN_PREPARE hotplug CPU notifier
%patch311 -p1
# Register a cpu hotplug notifier to reinitialize the scheduler domains hierarchy
%patch312 -p1
# Make arch_destroy_sched_domains() conditional
%patch313 -p1
# Use CPU_DOWN_FAILED notifier in the sched-domains hotplug code
%patch314 -p1
# PPC64 sigsuspend stomping on r4 and r5
%patch315 -p1
# Enable ICOM serial driver
%patch316 -p1
# IBM VSCSI driver race fix
%patch317 -p1
# Ensure PPC64 interrupts don't end up hard-disabled
%patch318 -p1
# Add PURR and version data to /proc/ppc64/lparcfg
%patch319 -p1
# Convert to using ibm,read-slot-reset-state2 RTAS call
%patch320 -p1
# Fix inability to find space for TCE table on ppc64
%patch321 -p1
# Prevent block device queues from being shared in viocd
%patch322 -p1
# Align PACA buffer for ppc64 hypervisor's use
%patch323 -p1
# Indicate that the veth link is always up
%patch324 -p1
# Quiesce OpenFirmware stdin device at boot.
%patch325 -p1
# Make ppc64's pci_alloc_consistent() conform to documentation
%patch326 -p1
# fix stack alignment for signal handlers on ppc64
%patch327 -p1
# Provide working PCI EEH error recovery on ppc64 (#135115)
%patch328 -p1
# Move idle loop setup to after main ppc64 arch setup init. (#142634)
%patch329 -p1
# Provide 64-bit translations for 32-bit TIOCMIWAIT/TIOCGICOUNT ioctls
%patch330 -p1
# Fix PPC64 pSeries VPA registration
%patch331 -p1
# Fix communication to PROM to close stdin on PPC64
%patch332 -p1
# Implement h/w PPC64 CPU utilisation data gathering
%patch333 -p1
# Stop xmon=on from jumping immediately into xmon on ppc64
%patch334 -p1
# Fix race and memory leak in iSeries veth module unloading
%patch335 -p1
# Prevent an iSeries partition oopsing with no CDROM drive.
%patch336 -p1
# IBM veth driver buffer starvation fix
%patch337 -p1
# Don't map objects to non-existent PPC64 NUMA nodes
%patch338 -p1
# Fix PPC64 NUMA's handling of memory nodes with holes in them
%patch339 -p1


#
# ia64
#

# Basic build fixes
%patch400 -p1
%patch401 -p1
%patch402 -p1
%patch403 -p1
%patch404 -p1
%patch405 -p1
%patch406 -p1
%patch407 -p1
%patch408 -p1
%patch409 -p1
%patch410 -p1
%patch411 -p1
%patch412 -p1
%patch413 -p1
%patch414 -p1
%patch415 -p1
%patch416 -p1
%patch417 -p1
%patch418 -p1

#
# s390
#

# Basic build fixes
%patch500 -p1
# Auto raidstart for S390
%patch501 -p1
# Fix fake_ll for QETH device  (#136175)
%patch502 -p1
# Recover after aborted nameserver request.
%patch503 -p1
# zfcp: Kernel stack frame for zfcp_cfdc_dev_ioctl() is too big
%patch504 -p1
# Fixed buffers for DASD devices.
%patch506 -p1
# Fix coredumps on S390
%patch507 -p1
# lcs device will not start anymore after first detection.
%patch508 -p1
# Fix possible failure of IP addr registration
%patch509 -p1
# Support broadcast on z800/z900 HiperSockets
%patch510 -p1
# fix race condition on s390 when going idle
%patch511 -p1
# include watchdog config on s390
%patch512 -p1
# introduce sequence numbers for lcs packets.
%patch513 -p1
# qeth fake_ll fixes
%patch514 -p1
# delay dasd retries to prevent i/o error
%patch515 -p1
# s390 qdio packet loss
%patch516 -p1
# Fix various problems in s390 common I/O layer.
%patch517 -p1
# s390 common i/o layer vary on/off
%patch518 -p1
# s390 qdio time delay missing interrupt problem
%patch519 -p1

#
# Patches 500 through 1000 are reserved for bugfixes to the core system
# and patches related to how RPMs are build
#


# This patch adds a "make nonint_oldconfig" which is non-interactive and
# also gives a list of missing options at the end. Useful for automated
# builds (as used in the buildsystem).
%patch900 -p1


#
# The execshield patch series, broken into smaller pieces
#
# 1) Exec shield core
%patch910 -p1
# 2) Option to printk fatal signals, useful for debugging
%patch911 -p1
# 3) The Execshield VA rearrangements
%patch912 -p1

#
# 4G/4G split
#
%patch920 -p1 -R
%patch921 -p1
%patch922 -p1
%patch923 -p1
%patch924 -p1

#
# Patch that adds a __must_check attribute for functions for which checking
# the return value is mantadory (eg copy_from_user)
#
%patch930 -p1

#
# TUX
#
%patch940 -p1

#
# GPG signed kernel modules
#
%patch950 -p1
%patch951 -p1
%patch952 -p1
%patch953 -p1
%patch954 -p1
%patch955 -p1
%patch956 -p1


#
# Patches 1000 to 4999 are reserved for bugfixes to drivers and filesystems
#


# add vidfail capability; 
# without this patch specifying a framebuffer on the kernel prompt would
# make the boot stop if there's no supported framebuffer device; this is bad
# for the installer cd that wants to automatically fall back to textmode
# in that case
%patch1000 -p1

#
# Fix the extreme stack usage in some kernel functions
#
%patch1020 -p1


# EXT3 bits.
# Ext3 reservations. reduces fragmentation bigtime
%patch1030 -p1
%patch1031 -p1
# improves ext3's error logging when we encounter an on-disk corruption.
%patch1032 -p1
# ext3 online resize
%patch1033 -p1
# improves ext3's ability to deal with corruption on-disk
%patch1034 -p1
# Handle double-delete of indirect blocks
%patch1035 -p1
# Fix xattr/mbcache race
%patch1036 -p1
%patch1037 -p1
# Fix percpu data leak on umount of ext2/ext3
%patch1038 -p1
# Fix ext2/3 maximum size limits
%patch1039 -p1
# Fix ext3 release race.
%patch1040 -p1

#
# Make /dev/mem a need-to-know function 
#
%patch1050 -p1
%patch1051 -p1


#
# /dev/crash driver for the crashdump analysis tool
#
%patch1060 -p1

#
# Most^WAll users of sleep_on are broken; fix a bunch
#
%patch1070 -p1

#
# Ingo's patch for voluntary preemption
#
%patch1080 -p1
%patch1081 -p1

#
# Sata update
# 
%patch1100 -p1
%patch1101 -p1
%patch1102 -p1
%patch1103 -p1
%patch1104 -p1
%patch1105 -p1

#
# SCSI Bits.
#
# Additions to the SCSI whitelist to make card readers work.
%patch1120 -p1
# fix SCSI bounce limit
%patch1121 -p1
# AIC host raid support.
%patch1122 -p1
# SCSI midlayer updates from 2.6.10rc
%patch1123 -p1
# Avoid oops when insmod'ing aic79xx on machine without hardware
%patch1124 -p1
# scsi: Add reset ioctl capability to ULDs
%patch1125 -p1
# scsi: Update ips driver to 2.6.10rc version.
%patch1126 -p1
# avoid extra 'put' on devices in __scsi_iterate_device()
# http://marc.theaimsgroup.com/?l=linux-scsi&m=109886580930570&w=2
%patch1127 -p1
# Update Qlogic driver to 2.6.10-rc2
%patch1128 -p1
# cciss: fixes for clustering
%patch1129 -p1
# Fix USB forced remove oops
%patch1130 -p1
# Fix up scsi_test_unit_ready() to work correctly with CD-ROMs
%patch1131 -p1
# Plug leaks in error paths in aic driver
%patch1132 -p1
# Add refcounting to scsi command allocation
%patch1133 -p1
# return full SCSI status byte in SG_IO
%patch1134 -p1
# sg: Fix oops of sg_cmd_done and sg_release race
%patch1135 -p1
# aacraid: remove aac_handle_aif
%patch1136 -p1
# Prevent kernel panic if an application issues an ioctl with an unrecognized subopcode.
%patch1137 -p1
# Fix refcounting order in sd/sr, fixing cable pulls on USB storage.
%patch1138 -p1
# IOCTL integer overflow and information leak.
%patch1139 -p1


# Block / MD layer fixes.
# Fix blocklayer races
%patch1140 -p1
# fix bad segment coalescing in blk_recalc_rq_segments()
%patch1141 -p1
# cciss: Off-by-one error causing oops in CCISS_GETLUNIFO ioctl
%patch1142 -p1
# Fix sx8 device naming in sysfs
%patch1143 -p1
# blkdev_get_blocks(): handle eof
%patch1144 -p1
# Fix CCISS ioctl return code
%patch1145 -p1
# CCISS ID updates
%patch1146 -p1
# __getblk_slow can loop forever when pages are partially mapped
%patch1147 -p1
# md: fix two little bugs in raid10
%patch1150 -p1
# md: make sure md always uses rdev_dec_pending properly
%patch1151 -p1
# dm multipath: Add target message ioctl
%patch1152 -p1
# dm multipath: ioctl ref by device no
%patch1153 -p1
# dm: fix mirror log ref count
%patch1154 -p1
# dm multipath: Split suspend hook
%patch1155 -p1
# dm raid1: deadlock fix
%patch1156 -p1
# device-mapper: tidy error kprintfs
%patch1157 -p1
# linux-2.6.9-dm-add-dm_dev-name.patch
%patch1158 -p1
# dm multipath: bio details record/restore
%patch1159 -p1
# dm multipath: export mapinfo
%patch1160 -p1
# dm multipath.
%patch1161 -p1
# Fix 64 bit issues in device mapper.
%patch1162 -p1
# dm multipath: fix infinite suspend requeueing
%patch1163 -p1
# Avoid a bdget in device mapper.
%patch1164 -p1
# raid5/raid6 bi_max_vec fixes.
%patch1165 -p1
# fix multipath assembly bug
%patch1166 -p1

#
# Various upstream NFS/NFSD fixes.
#
%patch1200 -p1
%patch1201 -p1
%patch1202 -p1
%patch1203 -p1
%patch1204 -p1
%patch1205 -p1
%patch1206 -p1
%patch1207 -p1
%patch1208 -p1
%patch1209 -p1
%patch1210 -p1
%patch1211 -p1
%patch1212 -p1
%patch1213 -p1
%patch1214 -p1
%patch1215 -p1
%patch1216 -p1
%patch1217 -p1
%patch1218 -p1
%patch1219 -p1


# Networking fixes.
# Fix IPV6 MTU calculation
%patch1300 -p1
# vlan_dev: return 0 on vlan_dev_change_mtu success
%patch1301 -p1
# Handle SIOCGIFHWADDR NULL dev->dev_addr
%patch1302 -p1
# fix missing security_*() check in net/compat.c
%patch1303 -p1
# XFRM layer bug fixes
%patch1304 -p1
# Fix CMSG validation checks wrt. signedness.
%patch1305 -p1
# Fix memory leak in ip_conntrack_ftp
%patch1306 -p1
# [IPV4]: Do not leak IP options.
%patch1307 -p1
# /proc/net/route stale pointer OOPS fix
%patch1308 -p1
# bonding: avoid kernel panic when 802.3ad link brought down.
%patch1309 -p1
# sk_forward_alloc() BUG assertion fix
%patch1310 -p1
# TCP BIC bug fix
%patch1311 -p1
# Fix fragment corruption
%patch1312 -p1
# sctp: add receive buffer accounting to protocol
%patch1313 -p1
# Fix IPSEC SA sequence collision
%patch1314 -p1
# Fix sctp sendbuffer accounting
%patch1315 -p1

# NIC driver fixes.
# Fix problems with b44 & 4g/4g
%patch1350 -p1
# Use correct spinlock functions in token ring net code
%patch1351 -p1
# make tulip_stop_rxtx() wait for DMA to fully stop
%patch1352 -p1
# reload EEPROM values at rmmod for needy cards
%patch1353 -p1
# [TG3]: Fix fiber hw autoneg bounces
%patch1354 -p1
# e100: fix improper enabling of interrupts
%patch1355 -p1
# rx checksum support for gige nForce ethernet
%patch1356 -p1
# via-rhine: references __init code during resume
%patch1357 -p1
# Workaround for the E1000 erratum 23
%patch1358 -p1
# Workaround E1000 post-maturely writing back to TX descriptors
%patch1359 -p1
# e100/e1000: return -EINVAL when setting rx-mini or rx-jumbo
%patch1360 -p1
# E1000 64k-alignment fix
%patch1361 -p1
# s2io update
%patch1362 -p1
# E1000 update from 2.6.10
%patch1364 -p1
# e100 update to 3.3.6-k2
%patch1365 -p1
# avoid panic in e100_tx_timeout on ppc64
%patch1366 -p1
# sk98lin: add MODULE_DEVICE_TABLE entry
%patch1367 -p1
# tg3: update + support BCM5752
%patch1368 -p1
# E100: fix state machine handling w/ NAPI
%patch1369 -p1
# ICH7 IDs for E100
%patch1370 -p1
# e1000: avoid sleep in timer context
%patch1371 -p1
# e1000: flush workqueues on remove
%patch1372 -p1
# Some nVidia network controllers show up as bridges.
%patch1373 -p1

# ACPI bits
# Eliminate spurious ACPI breakpoint msgs
%patch1400 -p1
# Make LEqual less strict about operand types matching.
%patch1401 -p1
# Fix ACPI debug level
%patch1402 -p1
# Implement ACPI reset mechanism.
%patch1403 -p1

#
# Various crash dumping patches
#
%patch1500 -p1
%patch1501 -p1
%patch1510 -p1
%patch1520 -p1
%patch1521 -p1

%patch1530 -p1
%patch1540 -p1
%patch1541 -p1
%patch1542 -p1
%patch1543 -p1
%patch1544 -p1
%patch1545 -p1
%patch1546 -p1
%patch1547 -p1
%patch1548 -p1
%patch1549 -p1
%patch1550 -p1
%patch1551 -p1
%patch1552 -p1
%patch1553 -p1
%patch1554 -p1
%patch1555 -p1
%patch1556 -p1
%patch1557 -p1
%patch1558 -p1
%patch1559 -p1
%patch1560 -p1
%patch1561 -p1

#
# Various SELinux fixes from 2.6.10rc
#
%patch1600 -p1
%patch1601 -p1
%patch1602 -p1
%patch1603 -p1
%patch1604 -p1
%patch1605 -p1
# SELinux xattr for tmpfs (from 2.6.9-mm)
%patch1606 -p1
%patch1608 -p1
%patch1609 -p1
%patch1610 -p1

# Misc fixes
# Fix ps showing wrong ppid. (#132030)
%patch1700 -p1
# Make proc_pid_status not dereference dead task structs.
%patch1701 -p1
# Make EDD runtime configurable.
%patch1710 -p1
# Backport sysfs changes from 2.6.10 (#140372)
%patch1720 -p1
# Optimize away the unconditional write to debug registers on signal delivery path
%patch1730 -p1
# Add barriers to generic timer code to prevent race
%patch1740 -p1
# Fix problems with non-power-of-two sector size discs
%patch1750 -p1
# Add missing MODULE_VERSION tags to some modules.
%patch1760 -p1
# disable sw irqbalance/irqaffinity for e7520-e7320-e7525
%patch1780 -p1
# ASPM workaround for PCIe
%patch1781 -p1
# Hot-plug driver updates due to MSI change
%patch1782 -p1
# Workaround for 80332 IOP hot-plug problem
%patch1783 -p1
# ExpressCard hot-plug support for ICH6M
%patch1784 -p1
# Various PCI-X hotplug fixes
%patch1785 -p1
# hugetlb_get_unmapped_area fix
%patch1790 -p1
# Various statm accounting fixes
%patch1800 -p1
# Suppress ide-floppy 'medium not present' noise
%patch1810 -p1
# Fix possible hang in do_wait()
%patch1820 -p1
# flush error in pci_mmcfg_write
%patch1830 -p1
# Fix boot crash on VIA systems
%patch1840 -p1
# autofs4 - allow map update recognition
%patch1850 -p1
# Add additional tainting mechanisms.
%patch1860 -p1
%patch1861 -p1
%patch1862 -p1
# xtime correctness.
%patch1870 -p1
# pagevec alignment
%patch1880 -p1
# ia64/x86_64/s390 overlapping vma fix
%patch1890 -p1
# Remove Futex Warning
%patch1900 -p1
# Futex mmap_sem deadlock
%patch1901 -p1
# Make spinlock debugging panic instead of continue.
%patch1910 -p1
# Fix compat fcntl F_GETLK{,64}
%patch1920 -p1
# fix uninitialized variable in waitid(2)
%patch1930 -p1
# Missing Cache flushes in AGPGART code.
%patch1950 -p1
# Workaround broken pci posting in AGPGART.
%patch1951 -p1
# Bounds checking for vc resize
%patch1960 -p1
# fix & clean up zombie/dead task handling & preemption
%patch1970 -p1
# Don't cache /proc/pid dentry for dead process
%patch1971 -p1
# Random poolsize sysctl handler integer overflow.
%patch1990 -p1

#
# VM related fixes.
#
# Make the OOM killer less aggressive.
%patch2000 -p1
# vm_dirty_ratio initialisation fix.
%patch2001 -p1
# VM pageout throttling.
%patch2002 -p1
# Lower dirty limit for mappings which can't be cached in highmem
%patch2003 -p1
# Don't oomkill when congested
%patch2004 -p1
# Increment total_scanned var to throttle kswapd
%patch2005 -p1
# RLIMIT_MEMLOCK bypass and unpriveledged user DoS.
%patch2007 -p1
# tweak for the oomkiller.
%patch2009 -p1
# Print some extra debugging info on oom_kill.
%patch2010 -p1
# fix invalidate page race
%patch2011 -p1
# Fix the mincore syscall's error handling
%patch2012 -p1
# Fix DMA zone exhaustion problem
%patch2013 -p1
# Improve try_to_free_pages scanning
%patch2014 -p1
# swap token NULL mm check
%patch2015 -p1

# IDE bits.
# Make CSB6 driver support configurations.
%patch2100 -p1
# Handle early EOF on CD's.
%patch2101 -p1
# Prevent panic with CD error
%patch2102 -p1
# Suppress Error Message on IDE probe
%patch2103 -p1
# Update IDE blacklist.
%patch2104 -p1

# USB bits
# IO edgeport overflows.
%patch2200 -p1
# Allow usb-storage to be reloaded
%patch2201 -p1

# SCSI bits.
# Drop the 'deprecated SG_IO warning'.
%patch2300 -p1
# fix incorrect hw segment counting in qla2x00 drivers
%patch2301 -p1
# aacraid: remove unused module parameter "commit"
%patch2302 -p1
# Update megaraid.
%patch2303 -p1
# Megaraid diskdump warnings.
%patch2304 -p1

#
# Local hack (off for any shipped kernels) to printk all files opened 
# the first 180 seconds after boot for debugging userspace startup 
# speeds
#
# %patch2999 -p1

#
# External drivers that are about to get accepted upstream
#

# Emulex FC
%patch3000 -p1
%patch3001 -p1
%patch3002 -p1
%patch3003 -p1

# Speedtouch
%patch3010 -p1

# Intel wireless
%patch3020 -p1
%patch3021 -p1
%patch3022 -p1
%patch3023 -p1
%patch3024 -p1
%patch3025 -p1

# Misc bits
# Various fixes from 2.6.10-ac
%patch4001 -p1
# Fix pty race condition on SMP machine
%patch4002 -p1
# AC97 ID additions.
%patch4003 -p1
# Fix Alt-Sysrq-B panics x86/x86_64
%patch4004 -p1
# Fix oops when io_setup is called with unwritable addr
%patch4005 -p1
# Various ptrace fixes.
%patch4006 -p1
# set panic_on_oops=1 by default
%patch4007 -p1
# Fix shmget for ppc64, s390-64 & sparc64.
%patch4008 -p1
# Intel HD audio driver.
%patch4009 -p1
# gpt partition noprobe
%patch4010 -p1
# tmpfs caused truncate BUG()
%patch4013 -p1
# Silence some cpufreq warnings.
%patch4014 -p1
# Fix Vesafb probe error.
%patch4015 -p1
# Add support for a brace of Dell PCI serial cards
%patch4016 -p1
# Fix leak in autofs
%patch4017 -p1
# Fix tty locking.
%patch4018 -p1
# cope with faults in iret
%patch4019 -p1


# Security issues.
%patch5000 -p1
%patch5001 -p1
%patch5002 -p1
%patch5003 -p1
%patch5004 -p1
%patch5005 -p1
%patch5006 -p1
%patch5007 -p1
%patch5008 -p1
%patch5009 -p1
%patch5010 -p1
%patch5011 -p1
%patch5012 -p1
%patch5013 -p1
%patch5014 -p1
%patch5015 -p1
%patch5016 -p1
%patch5017 -p1
%patch5018 -p1
%patch5019 -p1
%patch5020 -p1
%patch5021 -p1
%patch5022 -p1
%patch5023 -p1
# Security fixes without CAN-CVE's yet.
%patch5100 -p1

#
# final stuff
#

#
# misc small stuff to make things compile or otherwise improve performance
#
%patch10000 -p1

# Remove a bunch of exports that went away in 2.6.10rc1
%patch10001 -p1


%patch20000 -p1 -b .p20000
%patch20001 -p1 -b .p20001
%patch20002 -p1 -b .p20002
%patch20003 -p1 -b .p20003
%patch20004 -p1 -b .p20004
%patch20005 -p1 -b .p20005
%patch20006 -p1 -b .p20006
%patch20007 -p1 -b .p20007
%patch20008 -p1 -b .p20008
%patch20009 -p1 -b .p20009

%patch20010 -p1 -b .p20010
%patch20011 -p1 -b .p20011
%patch20012 -p1 -b .p20012
%patch20013 -p1 -b .p20013
%patch20014 -p1 -b .p20014
%patch20015 -p1 -b .p20015
%patch20016 -p1 -b .p20016
%patch20017 -p1 -b .p20017
%patch20018 -p1 -b .p20018
%patch20019 -p1 -b .p20020
%patch20020 -p1 -b .p20020
%patch20021 -p1 -b .p20021
%patch20022 -p1 -b .p20022
%patch20024 -p1 -b .p20024
%patch20025 -p1 -b .p20025
%patch20026 -p1 -b .p20046
%patch20027 -p1 -b .p20047
%patch20028 -p1 -b .p20048
%patch20029 -p1 -b .p20049
%patch20030 -p1 -b .p20030
%patch20031 -p1 -b .p20031
%patch20032 -p1 -b .p20032
%patch20033 -p1 -b .p20033
%patch20034 -p1 -b .p20034
%patch20035 -p1 -b .p20035
%patch20036 -p1 -b .p20036
%patch20037 -p1 -b .p20037
%patch20038 -p1 -b .p20038
%patch20040 -p1 -b .p20040
%patch20041 -p1 -b .p20041
%patch20042 -p1 -b .p20042
%patch20043 -p1 -b .p20043
%patch20044 -p1 -b .p20044
%patch20045 -p1 -b .p20045
%patch20046 -p1 -b .p20046
%patch20047 -p1 -b .p20047
%patch20048 -p1 -b .p20048
%patch20049 -p1 -b .p20049
%patch20050 -p1 -b .p20050
%patch20051 -p1 -b .p20051
%patch20052 -p1 -b .p20052
%patch20053 -p1 -b .p20053
%patch20054 -p1 -b .p20054
%patch20055 -p1 -b .p20055
%patch20056 -p1 -b .p20056
%patch20057 -p1 -b .p20057
%patch20058 -p1 -b .p20058
%patch20059 -p1 -b .p20059
%patch20060 -p1 -b .p20060
%patch20061 -p1 -b .p20061
%patch20062 -p1 -b .p20062
%patch20063 -p1 -b .p20063

%patch20070 -p1 -b .p20070
%patch20071 -p1 -b .p20071
%patch20072 -p1 -b .p20072
%patch20073 -p1 -b .p20073

%patch20080 -p1 -b .p20080
%patch20081 -p1 -b .p20081
%patch20082 -p1
%patch20083 -p1
%patch20084 -p1

%patch20100 -p1
%patch20101 -p0
%patch20102 -p1
%patch20103 -p1
%patch20104 -p1
%patch20105 -p1
%patch20106 -p1
%patch20107 -p1

# END OF PATCH APPLICATIONS

cp %{SOURCE10} Documentation/

mkdir configs

cp -fv %{all_arch_configs} .


# now run oldconfig over all the config files
for i in *.config 
do 
	mv $i .config 
	make ARCH=`echo $i | cut -d"-" -f3 | cut -d"." -f1 | sed -e s/i.86/i386/ -e s/s390x/s390/ -e s/ppc64.series/ppc64/  ` nonint_oldconfig > /dev/null 
	cp .config configs/$i 
done

# make sure the kernel has the sublevel we know it has. This looks weird
# but for -pre and -rc versions we need it since we only want to use
# the higher version when the final kernel is released.
perl -p -i -e "s/^SUBLEVEL.*/SUBLEVEL = %{sublevel}/" Makefile
perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -prep/" Makefile

# get rid of unwanted files resulting from patch fuzz
find . -name "*.orig" -exec rm -fv {} \;
find . -name "*~" -exec rm -fv {} \;


###
### build
###
%build

#
# Create gpg keys for signing the modules
#

gpg --homedir . --batch --gen-key %{SOURCE11} 
gpg --homedir . --export --keyring ./kernel.pub Red > extract.pub
make linux-%{kversion}/scripts/bin2c
linux-%{kversion}/scripts/bin2c ksign_def_public_key __initdata < extract.pub > linux-%{kversion}/crypto/signature/key.h

cd linux-%{kversion}



BuildKernel() {

    # Pick the right config file for the kernel we're building
    if [ -n "$1" ] ; then
	Config=kernel-%{kversion}-%{_target_cpu}-$1.config
	DevelDir=/usr/src/kernels/%{KVERREL}-$1-%{_target_cpu}
    else
	Config=kernel-%{kversion}-%{_target_cpu}.config
	DevelDir=/usr/src/kernels/%{KVERREL}-%{_target_cpu}
    fi

    KernelVer=%{version}-%{release}$1
    echo BUILDING A KERNEL FOR $1 %{_target_cpu}...

    # make sure EXTRAVERSION says what we want it to say
    perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -%{release}$1/" Makefile

    # and now to start the build process

    make -s mrproper
    cp configs/$Config .config

    make -s nonint_oldconfig > /dev/null
    make -s include/linux/version.h 

    make -s %{?_smp_mflags} %{make_target}
    make -s %{?_smp_mflags} modules || exit 1
    make buildcheck
    
    # Start installing the results

    mkdir -p $RPM_BUILD_ROOT/usr/lib/debug/boot
    mkdir -p $RPM_BUILD_ROOT/%{image_install_path}
    install -m 644 .config $RPM_BUILD_ROOT/boot/config-$KernelVer
    install -m 644 System.map $RPM_BUILD_ROOT/boot/System.map-$KernelVer
    cp arch/*/boot/bzImage $RPM_BUILD_ROOT/%{image_install_path}/vmlinuz-$KernelVer
    cp arch/*/boot/zImage.stub $RPM_BUILD_ROOT/%{image_install_path}/zImage.stub-$KernelVer || :

    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer
    make -s INSTALL_MOD_PATH=$RPM_BUILD_ROOT modules_install KERNELRELEASE=$KernelVer
%if %{kabi}
    mkdir -p $RPM_BUILD_ROOT/lib/modules/kabi-%{kabi_major}-%{kabi_minor}$1
%endif
 
    # And save the headers/makefiles etc for building modules against
    #
    # This all looks scary, but the end result is supposed to be:
    # * all arch relevant include/ files
    # * all Makefile/Kconfig files
    # * all script/ files 

    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/source
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    (cd $RPM_BUILD_ROOT/lib/modules/$KernelVer ; ln -s build source)
    # first copy everything
    cp --parents `find  -type f -name Makefile -o -name "Kconfig*"` $RPM_BUILD_ROOT/lib/modules/$KernelVer/build 
    cp Module.symvers $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    # then drop all but the needed Makefiles/Kconfig files
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Documentation
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    cp arch/%{_arch}/kernel/asm-offsets.s $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch}/kernel || :
    cp .config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a scripts $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a arch/%{_arch}/scripts $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch} || :
    cp -a arch/%{_arch}/*lds $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch}/ || :
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/*.o
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/*/*.o
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    cd include
    cp -a acpi config linux math-emu media net pcmcia rxrpc scsi sound video asm asm-generic $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    cp -a `readlink asm` $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    # Make sure the Makefile and version.h have a matching timestamp so that
    # external modules can be built
    touch -r $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Makefile $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/linux/version.h
    touch -r $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/.config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/linux/autoconf.h
    cd .. 

    #
    # save the vmlinux file for kernel debugging into the kernel-debuginfo rpm
    #
    mkdir -p $RPM_BUILD_ROOT/usr/lib/debug/lib/modules/$KernelVer
    cp vmlinux $RPM_BUILD_ROOT/usr/lib/debug/lib/modules/$KernelVer

    # gpg sign the modules
%if %{signmodules}
    gcc -o scripts/modsign/mod-extract scripts/modsign/mod-extract.c -Wall
	KEYFLAGS="--no-default-keyring --homedir .." 
	KEYFLAGS="$KEYFLAGS --secret-keyring ../kernel.sec" 
	KEYFLAGS="$KEYFLAGS --keyring ../kernel.pub" 
	export KEYFLAGS 
    for i in ` find $RPM_BUILD_ROOT/lib/modules/$KernelVer -name "*.ko" -type f` ; do
	sh ./scripts/modsign/modsign.sh $i Red
        mv -f $i.signed $i
    done
	unset KEYFLAGS
%endif

    # mark modules executable so that strip-to-file can strip them
    find $RPM_BUILD_ROOT/lib/modules/$KernelVer -name "*.ko" -type f  | xargs chmod u+x

    # detect missing or incorrect license tags
    for i in `find $RPM_BUILD_ROOT/lib/modules/$KernelVer -name "*.ko" ` ; do echo -n "$i " ; /sbin/modinfo -l $i >> modinfo ; done
    cat modinfo | grep -v "^GPL" | grep -v "^Dual BSD/GPL" | grep -v "^Dual MPL/GPL" | grep -v "^GPL and additional rights" | grep -v "^GPL v2" && exit 1 
    rm -f modinfo
    # remove files that will be auto generated by depmod at rpm -i time
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.*

    # Move the devel headers out of the root file system
    mkdir -p $RPM_BUILD_ROOT/usr/src/kernels
    mv $RPM_BUILD_ROOT/lib/modules/$KernelVer/build $RPM_BUILD_ROOT/$DevelDir
    ln -sf $DevelDir $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
}

###
# DO it...
###

# prepare directories
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/boot

%if %{buildup}
BuildKernel
%endif

%if %{buildsmp}
BuildKernel smp
%endif

%if %{buildhugemem}
BuildKernel hugemem
%endif

###
### install
###

%install

cd linux-%{kversion}

# architectures that don't get kernel-source (i586/i686/athlon) dont need
# much of an install because the build phase already copied the needed files

%if %{builddoc}
mkdir -p $RPM_BUILD_ROOT/usr/share/doc/kernel-doc-%{kversion}/Documentation

# sometimes non-world-readable files sneak into the kernel source tree
chmod -R a+r *
# copy the source over
tar cf - Documentation | tar xf - -C $RPM_BUILD_ROOT/usr/share/doc/kernel-doc-%{kversion}
%endif

%if %{buildsource}

mkdir -p $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}
chmod -R a+r *

# clean up the source tree so that it is ready for users to build their own
# kernel
make -s mrproper
# copy the source over
tar cf - . | tar xf - -C $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}

# set the EXTRAVERSION to <version>custom, so that people who follow a kernel building howto
# don't accidentally overwrite their currently working moduleset and hose
# their system
perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -%{release}custom/" $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/Makefile

# some config options may be appropriate for an rpm kernel build but are less so for custom user builds,
# change those to values that are more appropriate as default for people who build their own kernel.
perl -p -i -e "s/^CONFIG_DEBUG_INFO.*/# CONFIG_DEBUG_INFO is not set/" $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/configs/*
perl -p -i -e "s/^.*CONFIG_DEBUG_PAGEALLOC.*/# CONFIG_DEBUG_PAGEALLOC is not set/" $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/configs/*
perl -p -i -e "s/^.*CONFIG_DEBUG_SLAB.*/# CONFIG_DEBUG_SLAB is not set/" $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/configs/*
perl -p -i -e "s/^.*CONFIG_DEBUG_SPINLOCK.*/# CONFIG_DEBUG_SPINLOCK is not set/" $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/configs/*
perl -p -i -e "s/^.*CONFIG_DEBUG_HIGHMEM.*/# CONFIG_DEBUG_HIGHMEM is not set/" $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/configs/*
perl -p -i -e "s/^.*CONFIG_MODULE_SIG.*/# CONFIG_MODULE_SIG is not set/" $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/configs/*

install -m 644 %{SOURCE10}  $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}
%endif

###
### clean
###

%clean
rm -rf $RPM_BUILD_ROOT

###
### scripts
###

# load the loop module for upgrades...in case the old modules get removed we have
# loopback in the kernel so that mkinitrd will work.
%pre 
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
exit 0

%pre smp
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
exit 0

%pre hugemem
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
exit 0

%post 
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade
[ -x /sbin/new-kernel-pkg ] && /sbin/new-kernel-pkg --package kernel --mkinitrd --depmod --install %{KVERREL}

%post devel
if [ -x /usr/sbin/hardlink ] ; then
pushd /usr/src/kernels/%{KVERREL}-%{_target_cpu} > /dev/null ; {
	cd /usr/src/kernels/%{KVERREL}-%{_target_cpu}
	find . -type f | while read f; do hardlink -c /usr/src/kernels/*/$f $f ; done
}
popd > /dev/null
fi

%post smp
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade
[ -x /sbin/new-kernel-pkg ] && /sbin/new-kernel-pkg --package kernel-smp --mkinitrd --depmod --install %{KVERREL}smp

%post smp-devel
if [ -x /usr/sbin/hardlink ] ; then
pushd /usr/src/kernels/%{KVERREL}-smp-%{_target_cpu} > /dev/null ; {
	cd /usr/src/kernels/%{KVERREL}-smp-%{_target_cpu}
	find . -type f | while read f; do hardlink -c /usr/src/kernels/*/$f $f ; done
}
popd > /dev/null
fi

%post hugemem
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade
[ -x /sbin/new-kernel-pkg ] && /sbin/new-kernel-pkg --package kernel-hugemem --mkinitrd --depmod --install %{KVERREL}hugemem

%post hugemem-devel
if [ -x /usr/sbin/hardlink ] ; then
pushd /usr/src/kernels/%{KVERREL}-hugemem-%{_target_cpu} > /dev/null ; {
	cd /usr/src/kernels/%{KVERREL}-hugemem-%{_target_cpu}
	find . -type f | while read f; do hardlink -c /usr/src/kernels/*/$f $f ; done
}
popd > /dev/null
fi

%preun 
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
[ -x /sbin/new-kernel-pkg ] && /sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}

%preun smp
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
[ -x /sbin/new-kernel-pkg ] && /sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}smp

%preun hugemem
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
[ -x /sbin/new-kernel-pkg ] && /sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}hugemem


###
### file lists
###

%if %{buildup}
%files 
%defattr(-,root,root)
/%{image_install_path}/*-%{KVERREL}
/boot/System.map-%{KVERREL}
/boot/config-%{KVERREL}
%dir /lib/modules/%{KVERREL}
/lib/modules/%{KVERREL}/kernel
%if %{kabi}
%dir /lib/modules/kabi-%{kabi_major}-%{kabi_minor}
%endif

%files devel
%defattr(-,root,root)
/lib/modules/%{KVERREL}/build
/lib/modules/%{KVERREL}/source
%verify(not mtime) /usr/src/kernels/%{KVERREL}-%{_target_cpu}
%endif

%if %{buildsmp}
%files smp
%defattr(-,root,root)
/%{image_install_path}/*-%{KVERREL}smp
/boot/System.map-%{KVERREL}smp
/boot/config-%{KVERREL}smp
%dir /lib/modules/%{KVERREL}smp
/lib/modules/%{KVERREL}smp/kernel
%if %{kabi}
%dir /lib/modules/kabi-%{kabi_major}-%{kabi_minor}smp
%endif

%files smp-devel
%defattr(-,root,root)
/lib/modules/%{KVERREL}smp/build
/lib/modules/%{KVERREL}smp/source
%verify(not mtime) /usr/src/kernels/%{KVERREL}-smp-%{_target_cpu}
%endif

%if %{buildhugemem}
%files hugemem
%defattr(-,root,root)
/%{image_install_path}/*-%{KVERREL}hugemem
/boot/System.map-%{KVERREL}hugemem
/boot/config-%{KVERREL}hugemem
%dir /lib/modules/%{KVERREL}hugemem
/lib/modules/%{KVERREL}hugemem/kernel
%if %{kabi}
%dir /lib/modules/kabi-%{kabi_major}-%{kabi_minor}hugemem
%endif

%files hugemem-devel
%defattr(-,root,root)
/lib/modules/%{KVERREL}hugemem/build
/lib/modules/%{KVERREL}hugemem/source
%verify(not mtime) /usr/src/kernels/%{KVERREL}-hugemem-%{_target_cpu}
%endif

# only some architecture builds need kernel-source and kernel-doc

%if %{buildsource}
%files sourcecode
%defattr(-,root,root)
/usr/src/linux-%{KVERREL}/
%endif


%if %{builddoc}
%files doc
%defattr(-,root,root)
/usr/share/doc/kernel-doc-%{kversion}/Documentation/*
%endif

%changelog
* Wed Oct 19 2005 David Woodhouse <dwmw2@redhat.com> audit.90
- Fix sysctl races (CAN-2005-2709)

* Tue Oct 18 2005 David Woodhouse <dwmw2@redhat.com> audit.89
- Fix names_cache memory leak

* Mon Aug  8 2005 David Woodhouse <dwmw2@redhat.com> audit.88
- Fix sigsuspend exit on PPC64 to go via audit_syscall_exit()
- Allow filtering on success or failure

* Mon Aug  8 2005 David Woodhouse <dwmw2@redhat.com> audit.87
- Avoid marking the context auditable if no watches are actually triggered.

* Fri Aug  5 2005 David Woodhouse <dwmw2@redhat.com> audit.86
- Call audit_panic() if watch report fails

* Wed Aug  3 2005 David Woodhouse <dwmw2@redhat.com> audit.85
- Fix success/failure for PPC64 syscall rules

* Mon Aug  1 2005 David Woodhouse <dwmw2@redhat.com> audit.84
- Avoid duplicate syscall rules (Amy)

* Sun Jul 31 2005 David Woodhouse <dwmw2@redhat.com> audit.83
- Reduce lock contention in audit_data_get()

* Fri Jul 29 2005 David Woodhouse <dwmw2@redhat.com> audit.82
- Speed up audit_filter_syscall() for the fast path
- Fix task refcounting in audit_free() and audit_syscall_exit()
- Remove audit_zero_context() in audit_syscall_exit()

* Tue Jul 16 2005 David Woodhouse <dwmw2@redhat.com> audit.81
- Disable slab debugging

* Tue Jul 16 2005 David Woodhouse <dwmw2@redhat.com> audit.80
- Fix assertion in refcounting code

* Sat Jul 16 2005 David Woodhouse <dwmw2@redhat.com> audit.79
- Defer serial number generation until it's needed to avoid contention

* Fri Jul 15 2005 David Woodhouse <dwmw2@redhat.com> audit.78
- Fix livelock in audit_serial()

* Wed Jul 13 2005 David Woodhouse <dwmw2@redhat.com> audit.77
- Use GFP_ATOMIC from audit_free() to avoid scheduling in idle thread

* Wed Jul 13 2005 David Woodhouse <dwmw2@redhat.com> audit.76
- Avoid auditing the whole auditd process, not just the one thread

* Wed Jul 13 2005 David Woodhouse <dwmw2@redhat.com> audit.75
- Fix rmmod race condition with O_NONBLOCK
- Correct auditfs hooks

* Thu Jun 30 2005 David Woodhouse <dwmw2@redhat.com> audit.74
- Really don't audit auditd. For real this time. Honest.

* Thu Jun 30 2005 David Woodhouse <dwmw2@redhat.com> audit.73
- Quit waiting for backlog to clear once audit_panic() is called
- Add debugging to capture auditd getting audited.

* Fri Jun 24 2005 David Woodhouse <dwmw2@redhat.com> audit.72
- Add S390 again
- Final version of netlink fix

* Fri Jun 24 2005 David Woodhouse <dwmw2@redhat.com> audit.71
- Reduce loglevel of audit messages to KERN_NOTICE
- Netlink hashing fix forwarded by Chris

* Fri Jun 24 2005 David Woodhouse <dwmw2@redhat.com> audit.70
- Potential fix for auditfs_attach_wdata() oops

* Fri Jun 24 2005 David Woodhouse <dwmw2@redhat.com> audit.69
- Clean up user filtering method
- Add S390 again

* Fri Jun 24 2005 David Woodhouse <dwmw2@redhat.com> audit.68
- Fix user filtering to not always return true

* Thu Jun 23 2005 David Woodhouse <dwmw2@redhat.com> audit.67
- Clean up patches in -mm tree
- Really exempt auditd from being audited. Really. Honest.
- Drop S390 to work round their absence from the build system today.

* Wed Jun 22 2005 David Woodhouse <dwmw2@redhat.com> audit.66
- Revamp backlog wait patch for upstream -- add gfp_mask
- Allow USER_AVC messages when audit_enabled == 0
- Clean up threaded listing of rules and watches

* Mon Jun 20 2005 David Woodhouse <dwmw2@redhat.com> audit.65
- List watches from a kernel thread too

* Mon Jun 20 2005 David Woodhouse <dwmw2@redhat.com> audit.64
- Merge auditfs into one again
- More patches are in -mm
- Allow 5 more entries from non-sleeping contexts in backlog queue
- Protect auditd from OOM kill
- Fix locking in auditfs_attach_watch() harder
- List filter rules from kernel thread to avoid deadlock

* Mon Jun 20 2005 David Woodhouse <dwmw2@redhat.com> audit.63
- Wait for backlog to drain where possible

* Mon Jun 20 2005 David Woodhouse <dwmw2@redhat.com> audit.62
- Fix locking in auditfs_attach_wdata()
- Drop user messages if !audit_enabled
- Avoid auditing auditd in all cases

* Sun Jun 19 2005 David Woodhouse <dwmw2@redhat.com> audit.61
- Reorder patches again, merge auditfs patch
- Capture path_lookup() flags in audit_inode()

* Fri Jun 17 2005 David Woodhouse <dwmw2@redhat.com> audit.60
- Further auditfs cleanup (Tim)

* Fri Jun 17 2005 David Woodhouse <dwmw2@redhat.com> audit.59
- Add filters for user messages and watches

* Fri Jun 17 2005 David Woodhouse <dwmw2@redhat.com> audit.58
- Fix auditfs error handling, memory leak, watch removal (Tim)

* Tue Jun 14 2005 David Woodhouse <dwmw2@redhat.com> audit.57
- Merge selinux avc patches (#158957, #158968)

* Tue Jun 7 2005 David Woodhouse <dwmw2@redhat.com> audit.56
- Consolidate auditfs patches
- Multiple watches per inode, locking simplification (Tim)

* Fri Jun 4 2005 David Woodhouse <dwmw2@redhat.com> audit.55
- Make sure deleted watches stop happening.
- Free reserved inode audit data occasionally.

* Thu Jun 3 2005 David Woodhouse <dwmw2@redhat.com> audit.54
- Implicit pinning of watched inodes by use of i_state

* Thu Jun 2 2005 David Woodhouse <dwmw2@redhat.com> audit.53
- Fix module signing oops
- Sparse allocation of inode audit data

* Thu Jun 2 2005 David Woodhouse <dwmw2@redhat.com> audit.52
- Fix thinko in sys_socketcall. Having painstakingly copied the arguments
  in from userspace, let's then _use_ that copy instead of the users' copy.
- Abolish struct audit_wentry by merging it with struct audit_watch.
- Fix up error handling in fs/namei.c

* Thu May 25 2005 David Woodhouse <dwmw2@redhat.com> audit.51
- Enable slab debugging.
- Fix buffer overrun in audit_to_watch()
- Extra debugging for hash table
- Log current directory whenever we log a filename which may be relative

* Thu May 25 2005 David Woodhouse <dwmw2@redhat.com> audit.50
- Defer freeing of aux items to audit_free_aux()
- Remove items from hlist in audit_list_watches()
- Abolish inode->i_audit in favour of hash table

* Wed May 25 2005 David Woodhouse <dwmw2@redhat.com> audit.49
- Clean up logging of untrusted strings in avc.c (Stephen Smalley)
- auditfs update (Tim Chavez)

* Mon May 23 2005 David Woodhouse <dwmw2@redhat.com> audit.48
- Drop keys from syscall rules, since nobody could justify them
- Unify 'auid=' and put arch= before syscall= (Steve Grubb)

* Sat May 21 2005 David Woodhouse <dwmw2@redhat.com> audit.47
- Add serial # to user messages

* Fri May 20 2005 David Woodhouse <dwmw2@redhat.com> audit.46
- Defer d_path in AVC audit (Stephen Smalley)
- Clean up use of loginuid/auid and %d/%u (Steve Grubb)
- auditfs update (Tim Chavez)
- Fix AUDIT_USER messages (Steve Grubb)

- * Thu May 19 2005 David Woodhouse <dwmw2@redhat.com> audit.45
-  Move audit_notify_watch() back from vfs_permission to
   permission() where the 2.6.12 patch got misapplied.

- * Thu May 19 2005 David Woodhouse <dwmw2@redhat.com> audit.44
-  Honour audit_backlog_limit again
-  Reorder patches to reflect upstream status

- * Thu May 19 2005 David Woodhouse <dwmw2@redhat.com> audit.43
-  printk in audit_log_end() when no auditd
-  Don't audit auditd itself

- * Wed May 18 2005 David Woodhouse <dwmw2@redhat.com> audit.42
-  Restore Chris' third audit-to-skb patch

- * Wed May 18 2005 David Woodhouse <dwmw2@redhat.com> audit.41
-  Send audit messages from a kernel thread
-  Fix d_delete() deadlock with audit_dentry_unpin()

- * Tue May 17 2005 David Woodhouse <dwmw2@redhat.com> audit.40
-  Deal with entire range of userspace messages identically
-  Add key to syscall audit rules.

- * Tue May 17 2005 David Woodhouse <dwmw2@redhat.com> audit.39
-  Fix the memory corruption which was my fault.
-  Re-enable the auditfs patch which wasn't to blame at all.
-  Re-enable S390

- * Mon May 16 2005 David Woodhouse <dwmw2@redhat.com> audit.38
-  Disable the auditfs patch because it doesn't even boot.
-  Disable S390 again due to build system failure

- * Mon May 16 2005 David Woodhouse <dwmw2@redhat.com> audit.37
-  Audit socketcall arguments and sockaddrs copied from userspace
-  Re-enable SMP and hugemem kernels

- * Fri May 13 2005 David Woodhouse <dwmw2@redhat.com> audit.36
-  Auditfs #7U5a
-  Steve's patch logging untrusted strings, more types

- * Tue May 10 2005 David Woodhouse <dwmw2@redhat.com> audit.35
-  Message types.
-  Fix va_args abuse.

- * Tue May 10 2005 David Woodhouse <dwmw2@redhat.com> audit.34
-  Alternative fix for avc dcache_lock deadlock
-  Disable module signing.

- * Tue May 10 2005 David Woodhouse <dwmw2@redhat.com> audit.33
-  Call audit_filesystem_init() from _both_ audit_init() funcs.
-  Expand audit skb by enough to fit, not just AUDIT_BUFSIZ

- * Sat May  7 2005 David Woodhouse <dwmw2@redhat.com> audit.32
-  Fix nlmsg_len
-  Re-enable S390

- * Sat May  7 2005 David Woodhouse <dwmw2@redhat.com> audit.31
-  auditfs #7U4

- * Fri May  6 2005 David Woodhouse <dwmw2@redhat.com> audit.30
-  Patches from Herbert Xu to orphan and unshare netlink skbs
-  Spelling fixes from Steve

- * Fri May  6 2005 David Woodhouse <dwmw2@redhat.com> audit.29
-  Reorder patches to reflect what's upstream and in -mm now.
-  Add Chris' patches to log directly into skb.
-  Disable S390 again.

- * Tue May  3 2005 David Woodhouse <dwmw2@redhat.com> audit.28
-  Drop signal-logging patch in favour of Steve's version. 
-  Fix skb reuse corruption.
-  Add unrelated serial patch for i686 test box. 
-  Reenable s390/s390x

- * Fri Apr 29 2005 David Woodhouse <dwmw2@redhat.com> audit.27
-  Fix x86_64 auditing of i386 tasks. The syscall calling convention
   is different.
-  Exclude S390/S390X since those machines seem to be temporarily
   absent from the build farm.

- * Fri Apr 29 2005 David Woodhouse <dwmw2@redhat.com> audit.26
-  Fix the audit-kill printk so it's actually conditional
-  Reorder patches again to reflect what's in -mm

- * Fri Apr 29 2005 David Woodhouse <dwmw2@redhat.com> audit.25
-  auditfs #7U3
-  Log correct uid/pid when setting loginuid.
-  printk when auditd is killed as well as sending audit message

- * Sat Apr 23 2005 David Woodhouse <dwmw2@redhat.com> audit.24
-  auditfs #7U2
-  Include audit.h in fs/proc/base.c, net/netlink/af_netlink.c

- * Fri Apr 22 2005 David Woodhouse <dwmw2@redhat.com> audit.23
-  auditfs #7U1

- * Wed Apr 20 2005 David Woodhouse <dwmw2@redhat.com> audit.22
-  auditfs #7
-  Add NLMSG_READPRIV, NLMSG_RELAY netlink permissions.

- * Wed Apr 20 2005 David Woodhouse <dwmw2@redhat.com> audit.21
-  Include the part of the audit_log_task_info patch which avoids
   selinux dcache deadlocks.

- * Mon Apr 11 2005 David Woodhouse <dwmw2@redhat.com> audit.20
-  Move incorrectly-patched audit_notify_watch() from vfs_permission() 
   to permission().
-  Add cw's patch to requeue up to backlog limit in audit_log_drain

- * Wed Apr 6 2005 David Woodhouse <dwmw2@redhat.com> audit.19
-  auditfs #6 U3 in two parts
-  Audit signals sent to audit_pid

- * Fri Apr 1 2005 David Woodhouse <dwmw2@redhat.com> audit.18
-  IA64 syscall trace fix
-  auditfs #6 U2
-  AVC patch to log executable path

- * Fri Mar 25 2005 David Woodhouse <dwmw2@redhat.com> audit.17
-  auditfs #6 U1
-  Fix signed char error in audit_log_untrustedstring()
-  Drop auditfs-se patch which is now in Tim's patch
-  More patch reordering to track upstream

- * Tue Mar 23 2005 David Woodhouse <dwmw2@redhat.com> audit.16
-  minor fixes to auditarch patch
-  call audit_inode() in path_lookup() even when it's found in altroot
-  Fix s390{x,} build by including audit.h in ptrace.c

- * Tue Mar 22 2005 David Woodhouse <dwmw2@redhat.com> audit.15
-  Merge upstream patch to remove audit.h from fs.h
-  Add architecture field to syscall records
-  Fix ordering of ptrace and audit on syscall entry
-  Add explicit success/failure indication on syscall exit
-  Change syscall return to 'long'

- * Fri Mar 18 2005 David Woodhouse <dwmw2@redhat.com> audit.14
-  Add patch to dump names as hex if they're suspicious

- * Wed Mar 16 2005 David Woodhouse <dwmw2@redhat.com> audit.13
-  Reorder patches to vague semblance of the order they're going upstream.
-  SE Linux patch to allow AUDIT_WATCH_INS, AUDIT_WATCH_REM.

- * Wed Mar 16 2005 David Woodhouse <dwmw2@redhat.com> audit.12
- Auditfs patch #6
- Simplify forward struct definitions in audit.h

- * Tue Mar 8 2005 David Woodhouse <dwmw2@redhat.com> audit.11
-  Update to third attempt at including dev/uid/gid in audit_inode()

- * Tue Mar 8 2005 David Woodhouse <dwmw2@redhat.com> audit.10
-  Update to auditfs patch #5 "update 2"
-  Put fs_enabled at end of struct audit_status

- * Mon Feb 28 2005 David Woodhouse <dwmw2@redhat.com> audit.9
-  Reorder patches to put those which are already upstream first
-  Add Chris Wright's patch to include dev/uid/gid in audit_inode()
-  Add Chris Wright's patch to refrain from dropping high bits of ino#
-  Add Chris Wright's patch to fix netlink responses
-  Update to auditfs patch #5

- * Fri Feb 25 2005 David Woodhouse <dwmw2@redhat.com> audit.8
-  Merge Chris Wright's patches for congestion and audit_log_lost()
-  Update to auditfs patch #4

- * Fri Feb 25 2005 David Woodhouse <dwmw2@redhat.com> audit.7
-  Update to RHEL4 0-day erratum kernel-2.6.9-5.0.3_EL

- * Fri Feb 18 2005 David Woodhouse <dwmw2@redhat.com> audit.6
-  Fix list handling errors in IPC patch
-  Peter's temporary fix for AVC message corruption

- * Tue Feb 15 2005 David Woodhouse <dwmw2@redhat.com> audit.5
-  Update to v3 (2005-02-07) of auditfs patch.

- * Tue Feb 1 2005 David Woodhouse <dwmw2@redhat.com> audit.4
-  Log requested values of IPC_SET calls.
-  Make it boot on the Mac G5 test box.

- * Mon Jan 31 2005 David Woodhouse <dwmw2@redhat.com> audit.3
-  Update to second version of auditfs patch
-  Fix ppc64 syscall exit to use regs->result to correctly see errors

- * Thu Jan 20 2005 David Woodhouse <dwmw2@redhat.com> audit.2
-  Audit patches:
-   linux-2.6.9-audit-caps.patch
-   linux-2.6.9-audit-loginuid-proc.patch
-   linux-2.6.9-auditfs.patch
-   linux-2.6.9-audit-netlink-loginuid.patch
-   linux-2.6.9-ppc64-auditsyscall.patch
-   linux-2.6.9-auditoneliners.patch

* Fri May 20 2005 Dave Jones <davej@redhat.com> [2.6.9-11]
- Fix numa=off on x86-64.

* Thu May 12 2005 Dave Jones <davej@redhat.com> [2.6.9-10]
- Further fixing for the nVidia network controller problem.
- Fix wait_task_inactive() race. (#157424)

* Wed May 11 2005 Dave Jones <davej@redhat.com> [2.6.9-9]
- Fix data corruptor/local root in raw driver. (CAN-2005-1264)
- Fix ELF core dump privilege elevation. (CAN-2005-1263) (#157450)
- Avoid avc denial deadlock. (#154879)
- Don't map objects to non-existent PPC64 NUMA nodes. (#149132)
- Fix PPC64 NUMA's handling of memory nodes with holes in them.

* Mon May  9 2005 Dave Jones <davej@redhat.com> [2.6.9-8]
- Fix ABI regression in IA64 ptrace fix.
- Some nVidia network controllers show up as bridges. (#157240)
- Fix SATA issue when master supports LBA48 but slave doesn't. (#156875)

* Tue May  3 2005 Dave Jones <davej@redhat.com> [2.6.9-7]
- Rebuild.

* Tue May  3 2005 Dave Jones <davej@redhat.com> [2.6.9-6.47]
- Re-add E1000 MODULE_VERSION that got lost.

* Mon May  2 2005 Dave Jones <davej@redhat.com> [2.6.9-6.46]
- Fix regression with TEAC CD-210PU USB CD-ROM.  (#155870)
- Don't mess with IRQs when doing BogoMIPS calculation.

* Mon May  2 2005 Dave Jones <davej@redhat.com> [2.6.9-6.45]
- Fix possible crashme induced panic in page-fault handler on x86-64.

* Sat Apr 30 2005 Dave Jones <davej@redhat.com> [2.6.9-6.44]
- Fix sctp sendbuffer accounting. (#146797)

* Sat Apr 30 2005 Dave Jones <davej@redhat.com> [2.6.9-6.43]
- CAN-2005-0136 ptrace corner cases on ia64. (#155283)
- Redo fix to avoid sleep in timer context in E1000. (#154880,#154944,#154951)

* Wed Apr 27 2005 Dave Jones <davej@redhat.com> [2.6.9-6.42]
- Fix oopsable locking in NFS. (#152557)
- Fix incorrect use of memset/memcpy in ia64 ia32 signal handling.
- Cope with faults in iret/exec-shield bug (#154221, #154972)
- Potential NULL mm in swap token code. (#154639)

* Wed Apr 27 2005 Dave Jones <davej@redhat.com> [2.6.9-6.41]
- Fix up tty locking. (#152600, #155765)

* Fri Apr 22 2005 Dave Jones <davej@redhat.com> [2.6.9-6.40]
- Update the PCI EEH error recovery patch.

* Thu Apr 14 2005 Dave Jones <davej@redhat.com> [2.6.9-6.39]
- ata_piix: broken BIOS AHCI BAR setup work-around. (#154712)

* Wed Apr 13 2005 Dave Jones <davej@redhat.com> [2.6.9-6.38]
- Fix possible corruption in mmap over NFS. (#151284)
- Don't cache /proc/pid dentry for dead processes. (#147832)
- Add Itanium ZX2 chipset identification (#150110)
- Don't enable NUMA by default on dual core systems.

* Wed Mar 30 2005 Dave Jones <davej@redhat.com>
- Really apply patch for PCI EEH error recovery on ppc64.

* Mon Mar 28 2005 Dave Jones <davej@redhat.com> [2.6.9-6.37]
- Dual core support for AMD64.

* Mon Mar 28 2005 Dave Jones <davej@redhat.com> [2.6.9-6.36]
- Fix IP output route leak. (CAN-2005-0209)
- Fix oops when mounting Solaris NFSv4 volumes. (#152102)
- /proc/net/route stale pointer OOPS fix.

* Sun Mar 27 2005 Dave Jones <davej@redhat.com> [2.6.9-6.35]
- Additional fix for CAN-2005-0815

* Thu Mar 24 2005 Dave Jones <davej@redhat.com> [2.6.9-6.34]
- Fix potential DoS in ELF loader. (CAN-2005-0749)
- md: fix multipath assembly bug.
- diskdump cannot I/O on megaraid when the tasklet is in use (#151325)
- megaraid_diskdump_sleep actually sleeps for specified timeout (#151517)
- Fix information leak in ext2. (CAN-2005-0400)
- Further fixes to TCP BIC congestion handling.
- Add missing range checking in bluetooth. (CAN-2005-0750)
- Fix emulex lpfc driver LUN reset.
- Fix missing variable initialisation in clustered APIC code.

* Thu Mar 24 2005 Dave Jones <davej@redhat.com> [2.6.9-6.33]
- Keep fragment queues private to each user.

* Thu Mar 24 2005 Dave Jones <davej@redhat.com> [2.6.9-6.32]
- Improve scanning in try_to_free_pages(). (#147832)

* Tue Mar 22 2005 Dave Jones <davej@redhat.com> [2.6.9-6.31]
- NFS setclient improvements.
- lockd callback improvements.

* Mon Mar 21 2005 Dave Jones <davej@redhat.com> [2.6.9-6.30]
- ia64 unwind stack DOS. (CAN-2005-0135).
- Fix various ISO9660 handling flaws. (CAN-2005-0815)
- Fix swapped memset arguments in ieee802.11 code.
- e1000: avoid sleep in timer context.
- e1000: flush workqueues on remove.

* Mon Mar 21 2005 Dave Jones <davej@redhat.com> [2.6.9-6.29]
- Clustered APIC support for x86-64.

* Wed Mar 16 2005 Dave Jones <davej@redhat.com> [2.6.9-6.28]
- Fix IPSEC SA sequence collision. (#145424)
- Add missing crashdump_mode() check in x86_64 reboot code. (#151101)
- Update Emulex lpfc driver to 8.0.16.6

* Tue Mar 15 2005 Dave Jones <davej@redhat.com> [2.6.9-6.27]
- epoll: return proper error on overflow condition
- Fix up might_sleep warnings in previous futex deadlock fix.
- sctp: add receive buffer accounting to protocol.

* Tue Mar 15 2005 Dave Jones <davej@redhat.com> [2.6.9-6.26]
- Fix DMA zone exhaustion problems. (#142465)
- Fix IP fragment corruption. (#149589)
- CAN-2005-0384: Remote DoS on ppp. (#151240)

* Thu Mar 10 2005 Dave Jones <davej@redhat.com> [2.6.9-6.26]
- Add more diagnostic info to alt-sysrq-M.

* Tue Mar  8 2005 Dave Jones <davej@redhat.com> [2.6.9-6.25]
- shrink_cache() tweak to match upstream. (#147832)

* Sun Mar  6 2005 Dave Jones <davej@redhat.com> [2.6.9-6.24]
- Further fixing to the previous drm fix.

* Sat Mar  5 2005 Dave Jones <davej@redhat.com> [2.6.9-6.23]
- drm: fix race condition in radeon driver. (#149693)

* Sat Mar  5 2005 Dave Jones <davej@redhat.com> [2.6.9-6.22]
- Various cleanup of several patches (S390 common io fixes, Emulex update).
- Update megaraid driver. (#144810, #144902, #142539)
- Fix leak in error path in autofs.
- Fix release race in ext3. (#147443, #146037)

* Fri Mar  4 2005 Dave Jones <davej@redhat.com> [2.6.9-6.21]
- test

* Thu Mar  3 2005 Dave Jones <davej@redhat.com> [2.6.9-6.20]
- avoid a bdget in device mapper.
- IBM veth driver buffer starvation fix. (#147364)
- raid5/raid6 bi_max_vec fixes.
- Fix possible futex mmap_sem deadlock.
- Update Emulex lpfc driver to 8.0.16.3

* Thu Mar  3 2005 Dave Jones <davej@redhat.com> [2.6.9-6.19]
- Show extra debug info on page allocation failure.

* Thu Mar  3 2005 Dave Jones <davej@redhat.com> [2.6.9-6.18]
- Silence some cpufreq warnings. (#141983)
- Fix VESAFB probe error. (#142929)
- Add support for a bunch of Dell serial cards. (#146217)

* Wed Mar  2 2005 Dave Jones <davej@redhat.com> [2.6.9-6.17]
- s390: Fix for various problems in common i/o layer. (#133992)
- s390: common i/o layer vary on/off.
- s390: qdio time delay missing interrupt problem. (#145150)
- x86-64: Fix syscall/signal restart bug.
- Various size_t fixes. (CAN-2005-0531)
- ppc64: Fix race and memory leak in iSeries veth module unloading. (#144966)
- ppc64: Prevent an iSeries partition oopsing with no CDROM drive. (#146809)
- NFS: Fix O_DIRECT oops with oversized requests. (#148878)
- Only root should be able to set the N_MOUSE line discipline. (CAN-2005-0839)
- Fix tmpfs truncate BUG().
- Fix signedness issue in sysfs. (CAN-2005-0867)
- Remove Samsung SN-124 CD-ROM on DMA Blacklist. (#142937)
- Remainder of the previous diskdump deadlock fix. (#142167)

* Wed Mar  2 2005 Dave Jones <davej@redhat.com> [2.6.9-6.16]
- x86-64: Fix flush of multiple pages in change_page_attr
- Fix 64 bit issues in device mapper.
- dm multipath: fix infinite suspend requeueing

* Wed Mar  2 2005 Dave Jones <davej@redhat.com> [2.6.9-6.15]
- dm multipath: export mapinfo
- s390: qeth fake_ll fixes. (#136175)
- s390: delay dasd retries to prevent i/o error (#145115)
- s390: qdio didnt retry under some busy conditions. (#145116)
- Fix the mincore syscall's error handling. (#140523)
- ia64: wire up sys_waitid. (#137154)

* Tue Mar  1 2005 Dave Jones <davej@redhat.com>
- Don't probe last sector of a gpt partitioned disk. (#138563)

* Tue Mar  1 2005 Dave Jones <davej@redhat.com> [2.6.9-6.14]
- Additional fix for the earlier ACPI SRAT work.
- Fix possible diskdump deadlock (#142167)
- Intel HD audio support. (#146068, #146216)
- x86-64 huge pages fix. (#143472)
- device-mapper: Add dm_dev.name
- dm multipath: bio details record/restore.
- 802.11b/ipw2100/ipw2200 update. (#146763)

* Sat Feb 26 2005 Dave Jones <davej@redhat.com> [2.6.9-6.13]
- Put right the previous fix to scsi_disk_put() which was incorrect.
- Stop xmon=on from jumping immediately into xmon on ppc64. (#140751)
- reworked s390 dasd fixed buffers. (#134338)
- Fix oops in tg3_poll when using netconsole. (#143223)
- diskdump: remove "device has no block attribute" warning. (#146144)
- device-mapper: tidy error kprintfs
- ACPI reset support for x86. (#139104)
- Fix ia64 rx1600 pdh console. (#146274)
- Discover x86-64 NUMA topology through ACPI SRAT table.
- Silence additional deprecated SG_IO warning.
- Fix incorrect hw segment counting in qla2x00 drivers. (#140472)
- E100: fix state machine handling w/ NAPI (#140082)
- E100: Add PCI IDs for ICH7. (#146137)
- AHCI SATA fixes.
- Remove unused 'commit' parameter from aacraid. (#140780)

* Fri Feb 25 2005 Dave Jones <davej@redhat.com>
- avoid panic in e100_tx_timeout on ppc64. (#140116)
- sk98lin: add MODULE_DEVICE_TABLE entry
- Allow usb-storage to be reloaded. (#129165)
- diskdump support for megaraid. (#142736)
- ia64: Work around DMA timeouts on SGI IOC4 IDE. (#144265)
- sk_forward_alloc() BUG assertion fix. (#139430)
- Various ptrace fixes. (#143073,#146089,#132849,#133590,#140083,#147575)
- diskdump: add module parameter to disable WCE. (#146412)
- Clean up last remnants of kexec.
- TCP BIC bug fix
- Fix panic() w/panic_timeout hangs instead of rebooting. (#144668)
- Set panic_on_oops=1 by default. (#144657, #143993)
- tg3: update + support BCM5752. (#145105)
- Fix ext2/3 maximum size limits. (#143907)
- Fix shmget for ppc64, s390(64).
- dm raid1: deadlock fix.
- Implement h/w PPC64 CPU utilisation data gathering. (#144862)

* Thu Feb 24 2005 Dave Jones <davej@redhat.com>
- Remove non-working kexec functionality.
- bonding: avoid kernel panic when 802.3ad link brought down. (#146067)
- Update E1000 to 5.6.10.1-k2 (#146115)
- Update E100 to 3.3.6-k2 (#140082, #140116)
- s390: introduces sequence numbers for lcs packets. (#145118)
- Fixes to Intel Enhanced Speedstep support. (#138952)
- ia64 OS_INIT switch support.
- diskdump SATA support.
- NMI switch support for x86-64.

* Wed Feb 23 2005 Dave Jones <davej@redhat.com>
- SATA updates. (#132648, #145107)
- s2io driver update. (#138012)

* Tue Feb 22 2005 Dave Jones <davej@redhat.com>
- Intel ICH7 hardware support (PCI ID additions) (#144741)
- Fix HPET initialisation. (#147224, #134140)
- dm multipath: Add target message ioctl
- dm multipath: ioctl ref by device no
- dm multipath: Split suspend hook
- dm: fix mirror log refcount.
- fix i386 vsyscall-sysenter unwind info
- Add missing lock prefix to switch_to() on x86-64 (#146911)
- Fix PPC64 pSeries VPA registration. (#142634)
- Fix communication to PROM to close stdin on PPC64. (#145134)

* Sat Feb 19 2005 Dave Jones <davej@redhat.com>
- Handle a 64-bit MM being torn down from a 32-bit process. (#144356)
- Move idle loop setup to after main ppc64 arch setup init. (#142634)
- invalidate page race fix. (#140383)
- Fix up AGPGART PCI Posting bugs properly.
- Provide 64-bit translations for 32-bit TIOCMIWAIT/TIOCGICOUNT ioctls
- Fix race condition on s390 when going idle. (#142855, #144317)
- Include watchdog config on s390. (#139836)
- Suppress Error Message on IDE probe.
- Add cpu_relax() calls for various ia64 loops. (#141699)
- Fix oops when io_setup is called with unwritable addr. (#143050)

* Fri Feb 18 2005 Dave Jones <davej@redhat.com>
- AC97 quirk additions & dupicate cleanup.
- Fix Alt-Sysrq-B panics x86/x86_64 (#140792)

* Thu Feb 17 2005 Dave Jones <davej@redhat.com>
- NLM (NFSv3) problems when mounting with "sec=krb5" (#146703)
- Enable OProfile profile support for UP i686 kernel. (#139031)
- Fix stack alignment for signal handlers on ppc64. (#145064)
- Fix leak of percpu data structure on ext2/ext3 umount.
- Fix & clean up zombie/dead task handling & preemption. (#141284)
- Print some extra debugging info on oom_kill. (#142784)
- Fix pty race condition on SMP machine. (#129725)
- Fix up wrong argument order in dma_declare_coherent_memory()
- Fix sysfs_dir_close memory leak.
- Fix md bio refcount leak.
- Fix "RPC: garbage, exit EIO" when using NFSv3 with Kerberos 5 (#142464)
- Fix NFS Direct-IO stack usage. (#142857)

* Mon Feb  7 2005 Dave Jones <davej@redhat.com>
- Export get_sb_pseudo(). (#139436)
- Fix io port security hole on x86-64. (#146244)

* Wed Jan 26 2005 Dave Jones <davej@redhat.com>
- Fix shmctl SHM_LOCK perms. (#144471)
- Various fixes from 2.6.10-ac (#146095, #146101)
- OOM-killer tweak.

* Tue Jan 25 2005 Dave Jones <davej@redhat.com>
- Drop the deprecated SG_IO warning. (#141390)
- Close information leak in sysenter (#146083)
- Fix race in expand stack (CAN-2005-0001) (#144412)

* Mon Jan 17 2005 Dave Jones <davej@redhat.com>
- Fix flaws in IGMP code (CAN-2004-1137) (#142670)
- Fix several corner cases in the 4g4g patch. (#144131, #144658)
- Fix do_brk priveledge escalation. (CAN-2004-1235) (#144136)
- Fix insuffient locking in DRM code. (CAN-2004-1056) (#144391)
- Fix RLIMIT_MEMLOCK bypass and unpriveledged user DoS. (#144528)
- Fix random poolsize sysctl handler integer overflow. (#144532)
- Fix SCSI IOCTL integer overflow and information leak. (#144522)

* Wed Jan  5 2005 Dave Jones <davej@redhat.com>
- Fix AGP data corruption on non-4g4g kernels.

* Tue Jan  4 2005 Dave Jones <davej@redhat.com>
- Fix Tux crash if restarted with live connections that are in a particular
  state. (#140916)
- Fix regression introduced by the recent CMSG security fixes. (#143975)
- Various vm tuning to prevent possibility of OOM kill. (#141173)
  - Lower dirty limit for mappings which can't be cached in highmem
  - Don't oomkill when congested
  - Increment total_scanned var to throttle kswapd
- Prevent panic with CD errors.
- Enable SL82C104 IDE driver as built-in on PPC64 (#131033)

* Wed Dec 29 2004 Dave Jones <davej@redhat.com>
- Call module_upgrade in post stage of of kernel rpm installation.
- Fix bad diskdump interaction with recent sysfs update. (#142321)
- Fix refcounting order in sd/sr, fixing cable pulls on USB storage.

* Sun Dec 12 2004 Dave Jones <davej@redhat.com>
- Prevent kernel panic if an application issues an ioctl with an unrecognized subopcode.
- fix false ECHILD result from wait* with zombie group leader. (#142518)

* Sat Dec 11 2004 Dave Jones <davej@redhat.com>
- Work around broken PCI posting in AGPGART. (#138348)
- Make sure VC resizing fits in s16.

* Fri Dec 10 2004 Dave Jones <davej@redhat.com>
- Update yesterdays SELinux fix. (#142353)
- E1000 64k-alignment fix. (#140047)
- Disable tiglusb module. (#142102)
- ID updates for cciss driver.
- Fix overflows in USB Edgeport-IO driver. (#142258)
- Fix wrong TASK_SIZE for 32bit processes on x86-64. (#141737)
- Fix ext2/ext3 xattr/mbcache race. (#138951)
- Fix bug where __getblk_slow can loop forever when pages are partially mapped. (#140424)
- Add missing cache flushes in agpgart code.

* Thu Dec  9 2004 Dave Jones <davej@redhat.com>
- Prevent block device queues from being shared in viocd. (#139018)
- Libata updates. (#138405)
- aacraid: remove aac_handle_aif (#135527)
- fix uninitialized variable in waitid(2). (#142505)
- Fix CMSG validation checks wrt. signedness.
- Fix memory leak in ip_conntrack_ftp
- [IPV4]: Do not leak IP options. (#142251)
- ppc64: Align PACA buffer for hypervisor's use. (#141817)
- ppc64: Indicate that the veth link is always up. (#135402)
- ppc64: Quiesce OpenFirmware stdin device at boot. (#142009)
- SELinux: Fix avc_node_update oops. (#142353)
- Fix CCISS ioctl return code.
- Make ppc64's pci_alloc_consistent() conform to documentation. (#140047)

* Wed Dec  8 2004 Dave Jones <davej@redhat.com>
- Workaround E1000 post-maturely writing back to TX descriptors. (#133261)
- Fix the previous E1000 errata workaround.
- Several IDE fixes from 2.6.9-ac
- vm pageout throttling. (#133858)

* Tue Dec  7 2004 Dave Jones <davej@redhat.com>
- Fix Tux from oopsing. (#140918)
- Fix Tux/SELinux incompatability (#140916)
- Fix Tux/IPV6 problem. (#140916)
- ide: Fix possible oops on boot.
- Make spinlock debugging panic instead of printk.
- Update Emulex lpfc driver to 8.0.16
- Selected patches from 2.6.9-ac12
- ppc64: Fix inability to find space for TCE table (#138844)
- Fix compat fcntl F_GETLK{,64} (#141680)
- blkdev_get_blocks(): handle eof

* Mon Dec  6 2004 Dave Jones <davej@redhat.com>
- Bump redhat-rpm-config buildreq version.
- Do the Centrino/ACPI changes on x86-64 too.

* Fri Dec  3 2004 Dave Jones <davej@redhat.com>
- Introduce infrastructure for supporting kabi.
- Disable Centrino Speedstep driver.
- Change ACPI cpufreq driver from modular to built-in. (#138952)

* Thu Dec  2 2004 Dave Jones <davej@redhat.com>
- XFRM layer bug fixes
- ppc64: Convert to using ibm,read-slot-reset-state2 RTAS call
- ide: Make CSB6 driver support configurations.
- ide: Handle early EOF on CDs.
- Fix sx8 device naming in sysfs
- e100/e1000: return -EINVAL when setting rx-mini or rx-jumbo. (#140793)

* Wed Dec  1 2004 Dave Jones <davej@redhat.com>
- Workaround for the E1000 erratum 23 (#140047)
- Remove bogus futex warning. (#138179)
- x86_64: Fix lost edge triggered irqs on UP kernel.
- x86_64: Reenable DRI for MGA.
- Workaround E1000 post-maturely writing back to TX descriptors (#133261)
- 3c59x: add EEPROM_RESET for 3c900 Boomerang
- Fix buffer overrun in arch/x86_64/sys_ia32.c:sys32_ni_syscall()
- ext3: improves ext3's error logging when we encounter an on-disk corruption.
- ext3: improves ext3's ability to deal with corruption on-disk
- ext3: Handle double-delete of indirect blocks.
- Disable SCB2 flash driver for RHEL4. (#141142)

* Tue Nov 30 2004 Dave Jones <davej@redhat.com>
- x86_64: add an option to configure oops stack dump
- x86[64]: display phys_proc_id only when it is initialized
- x86_64: no TIOCSBRK/TIOCCBRK in ia32 emulation
- via-rhine: references __init code during resume
- Add barriers to generic timer code to prevent race. (#128242)
- ppc64: Add PURR and version data to /proc/ppc64/lparcfg
- Prevent xtime value becoming incorrect.
- scsi: return full SCSI status byte in SG_IO
- Fix show_trace() in irq context with CONFIG_4KSTACKS
- Adjust alignment of pagevec structure.
- md: make sure md always uses rdev_dec_pending properly.
- Make proc_pid_status not dereference dead task structs.
- sg: Fix oops of sg_cmd_done and sg_release race (#140648)
- fix bad segment coalescing in blk_recalc_rq_segments()
- fix missing security_*() check in net/compat.c
- ia64/x86_64/s390 overlapping vma fix
- Update Emulex lpfc to 8.0.15

* Mon Nov 29 2004 Dave Jones <davej@redhat.com>
- Add another card reader to whitelist. (#141022)
- Fix possible hang in do_wait() (#140042)
- Fix ps showing wrong ppid. (#132030)
- Print advice to use -hugemem if >=16GB of memory is detected.
- Enable ICOM serial driver. (#136150)
- Enable acpi hotplug driver for IA64.
- SCSI: fix USB forced remove oops.
- ia64: add missing sn2 timer mask in time_interpolator code. (#140580)
- ia64: Fix hang reading /proc/pal/cpu0/tr_info (#139571)
- ia64: bump number of UARTS. (#139100)
- Fix ACPI debug level (#141292)
- Make EDD runtime configurable, and reenable.
- ppc64: IBM VSCSI driver race fix. (#138725)
- ppc64: Ensure PPC64 interrupts don't end up hard-disabled. (#139020, #131590)
- ppc64: Yet more sigsuspend/singlestep fixing. (#140102, #137931)
- x86-64: Implement ACPI based reset mechanism. (#139104)
- Backport 2.6.10rc sysfs changes needed for IBM hotplug driver. (#140372)
- Update Emulex lpfc driver to v8.0.14
- Optimize away the unconditional write to debug registers on signal delivery path.
- Fix up scsi_test_unit_ready() to work correctly with CD-ROMs.
- md: fix two little bugs in raid10
- Remove incorrect ELF check from module loading. (#140954)
- Plug leaks in error paths of aic driver.
- Add refcounting to scsi command allocation.
- Taint oopses on machine checks, bad_page()'s calls and forced rmmod's.
- Share Intel cache descriptors between x86 & x86-64.
- rx checksum support for gige nForce ethernet
- vm: vm_dirty_ratio initialisation fix

* Mon Nov 22 2004 Dave Jones <davej@redhat.com>
- Update -ac patch to 2.6.9-ac11
- make tulip_stop_rxtx() wait for DMA to fully stop. (#138240)
- ACPI: Make LEqual less strict about operand types matching.
- scsi: avoid extra 'put' on devices in __scsi_iterate_device() (#138135)
- Fix bugs with SOCK_SEQPACKET AF_UNIX sockets
- Reenable token ring drivers. (#119345)
- SELinux: Map Unix seqpacket sockets to appropriate security class
- SELinux: destroy avtab node cache in policy load error path.
- AF_UNIX: Serialize dgram read using semaphore just like stream.
- lockd: NLM blocks locks don't sleep
- NFS lock recovery fixes
- Add more MODULE_VERSION tags (#136403)
- Update qlogic driver to 2.6.10rc2 level.
- cciss: fixes for clustering
- ieee802.11 update.
- ipw2100: update to ver 1.0.0
- ipw2200: update to ver 1.0.0
- Enable promisc mode on ipw2100
- 3c59x: reload EEPROM values at rmmod for needy cards
- ppc64: Prevent sigsuspend stomping on r4 and r5
- ppc64: Alternative single-step fix.
- fix for recursive netdump oops on x86_64
- ia64: Fix IRQ routing fix when booted with maxcpus=  (#138236)
- ia64: search the iommu for the correct size
- Deal with fraglists correctly on ipv4/ipv6 output
- Various statm accounting fixes (#139447)

* Sat Nov 20 2004 Dave Jones <davej@redhat.com>
- Reenable VESAfb. (#139982)
- Reenable CMM /proc interface for s390 (#137397)

* Fri Nov 19 2004 Dave Jones <davej@redhat.com>
- e100: fix improper enabling of interrupts. (#139706)
- autofs4: allow map update recognition 
- Various TCP fixes from 2.6.10rc
- Various netlink fixes from 2.6.10rc
- [IPV4]: Do not try to unhash null-netdev nexthops.
- ppc64: Make NUMA map CPU->node before bringing up the CPU (#128063)
- ppc64: sched domains / cpu hotplug cleanup. (#128063)
- ppc64: Add a CPU_DOWN_PREPARE hotplug CPU notifier (#128063)
- ppc64: Register a cpu hotplug notifier to reinitialize the
  scheduler domains hierarchy (#128063)
- ppc64: Introduce CPU_DOWN_FAILED notifier (#128063)
- ppc64: Make arch_destroy_sched_domains() conditional (#128063)
- ppc64: Use CPU_DOWN_FAILED notifier in the sched-domains hotplug code (#128063)
- Various updates to the SCSI midlayer from 2.6.10rc.
- vlan_dev: return 0 on vlan_dev_change_mtu success. (#139760)
- Update Emulex lpfc driver to v8.0.13
- Fix problem with b44 driver and 4g/4g patch. (#118165)
- Prevent oops when loading aic79xx on machine without hardware. (#125982)
- Use correct spinlock functions in token ring net code. (#135462)
- scsi: Add reset ioctl capability to ULDs
- scsi: update ips driver to 7.10.18
- Reenable ACPI hotplug driver. (#139976, #140130, #132691)

* Wed Nov 17 2004 Dave Jones <davej@redhat.com>
- Implement an RCU scheme for the SELinux AVC
- Improve on the OOM-killer taming patch.
- device-mapper: Remove duplicate kfree in dm_register_target error path.
- Make SHA1 guard against misaligned accesses
- ASPM workaround for PCIe. (#123360)
- Hot-plug driver updates due to MSI change (#134290)
- Workaround for 80332 IOP hot-plug problem (#139041)
- ExpressCard hot-plug support for ICH6M (#131800)
- Fix boot crash on VIA systems (noted on x86-64)
- PPC64: Store correct backtracking info in ppc64 signal frames
- PPC64: Prevent HVSI from oopsing on hangup (#137912)
- Fix poor performance b/c of noncacheable mapping in 4g/4g (#130842)
- Fix PCI-X hotplug issues (#132852, #134290)
- Re-export force_sig() (#139503)
- Various fixes for more security issues from latest -ac patch.

* Tue Nov 16 2004 Dave Jones <davej@redhat.com>
- Fix d_find_alias brokenness (#137791)
- tg3: Fix fiber hw autoneg bounces (#138738)
- diskdump: Fix issue with NMI watchdog. (#138041)
- diskdump: Export disk_dump_state. (#138132)
- diskdump: Tickle NMI watchdog in diskdump_mdelay() (#138036)
- diskdump: Fix mem= for x86-64 (#138139)
- diskdump: Fix missing system_state setting. (#138130)
- diskdump: Fix diskdump completion message (#138028)
- Re-add aic host raid support.
- Take a few more export removal patches from 2.6.10rc
- SATA: Make AHCI work
- SATA: Core updates.
- S390: Fix Incorrect registers in core dumps. (#138206)
- S390: Fix up lcs device state. (#131167)
- S390: Fix possible qeth IP registration failure.
- S390: Support broadcast on z800/z900 HiperSockets
- S390: Allow FCP port to recover after aborted nameserver request.
- Flush error in pci_mmcfg_write (#129338)
- hugetlb_get_unmapped_area fix (#135364, #129525)
- Fix ia64 cyclone timer on ia64 (#137842, #136684)
- Fix ipv6 MTU calculation. (#130397)
- ACPI: Don't display messages about ACPI breakpoints. (#135856)
- Fix x86_64 copy_user_generic (#135655)
- lockd: remove hardcoded maximum NLM cookie length
- Fix SCSI bounce limit

* Mon Nov 15 2004 Dave Jones <davej@redhat.com>
- Disable polling mode on hotplug controllers in favour of interrupt driven. (#138737)

* Sat Nov 13 2004 Dave Jones <davej@redhat.com>
- Drop some bogus patches.

* Thu Nov 11 2004 Dave Jones <davej@redhat.com>
- NFS: Fix dentry refcount accounting error
- Make sure that modules get signed with the right key.
- Remove SG_IO deprecation warning (#136179)
- s390: Fix fake_ll for qeth device. (#136175)
- s390: User process executing in wrong address-space mode
- s390: zfcp: Kernel stack frame for zfcp_cfdc_dev_ioctl() is too big
- s390: Use slab allocator for DASD I/O pages.
- PPC64: HVSI udbg support
- PPC64: Make HVSI console survive FSP reset
- PPC64: Make PCI hostbridge hotplugging work
- PPC64: Fix IBM VSCSI problems (#138124)

* Wed Nov 10 2004 Dave Jones <davej@redhat.com>
- Fix single-stepping on PPC64
- Integrate kernel-devel changes

* Tue Nov  9 2004 Dave Jones <davej@redhat.com>
- SELinux: netif fixes.
- SELinux: add DAC check to setxattr() hook.
- SELinux: sidtab locking fix.
- SELinux: mediate send_sigurg().
- SELinux: fix setscheduler hook deadlock.
- ide-floppy: Supresses error messages resulting from Medium not present

* Mon Nov  8 2004 Dave Jones <davej@redhat.com>
- Various IA64 updates from 2.6.10rc1
- nfsd: make sure getxattr inode op is non-NULL before calling it.

* Thu Nov  4 2004 Dave Jones <davej@redhat.com>
- Handle NULL dev->dev_addr in SIOCGIFHWADDR correctly. (#137648)
- Fix NFSD domainname size limit.
- nfsd4: nfsd oopsed when encountering a conflict with a local lock
- nfsd4: fix putrootfh return
- nfsd: Insecure port warning shows decimal IPv4 address
- Disable sw irqbalance/irqaffinity for e7520/e7320/e7525 (#136419)
- RAID1 failover hang fix (#136485)
- Add MODULE_VERSION to ixgb driver. (#136399, #137911)

* Tue Nov  2 2004 Dave Jones <davej@redhat.com>
- Fix exec-shield non-PIE/non-prelinked bug.
- ext3 reservations: fix goal hit accounting.
- Fix problems with non-power-of-two sector size discs. (#135094)
- Fix possible oops in netpoll (#132153)
- Add missing MODULE_VERSION tags to various modules. (#136399)
- Add USB card reader de jour. (#124048)

* Mon Nov  1 2004 Dave Jones <davej@redhat.com>
- Fix memory leak on x86-64 in mixed 32/64 mode. (#132947)
- Yet another USB card reader for the whitelist. (#137722)
- Remove a bunch of exports that went away in 2.6.10rc1.

* Fri Oct 29 2004 Dave Jones <davej@redhat.com>
- Stop E820 entries in zero page getting corrupted by EDID info. (#137510)
- Fix raid5 oops (#127862)
- Remove the possibility of some false OOM kills. (#131251)

* Tue Oct 26 2004 Dave Jones <davej@redhat.com>
- Add Intel wireless drivers for Centrino chipsets.

* Mon Oct 25 2004 Dave Jones <davej@redhat.com>
- Add more USB card readers to SCSI whitelist (#131546, #132923)

* Sat Oct 23 2004 Dave Jones <davej@redhat.com>
- Disable CONFIG_SCHED_SMT for iseries.

* Fri Oct 22 2004 Dave Jones <davej@redhat.com>
- Fix PPC NUMA (#130716).
- Fix autoraid for S390 (#123842/#130339)
- Selected bits from 2.6.9-ac3
  - Fix syncppp/async ppp problems with new hangup
  - Fix broken parport_pc unload
  - Stop i8xx_tco making some boxes reboot on load
  - Fix cpia/module tools deadlock
  - Security fix for smbfs leak/overrun

* Thu Oct 21 2004 Dave Jones <davej@redhat.com>
- Misc security fixes from 2.6.9-ac2

* Wed Oct 20 2004 Dave Jones <davej@redhat.com>
- Fix ia64 module loading (#136365)
- Enable CONFIG_PACK_STACK for s390.

* Tue Oct 19 2004 Dave Jones <davej@redhat.com>
- Fix NFS badness (#132726)
- Enable discontigmem for PPC64
- Disable a bunch of irrelevant options for PPC64
- Drop bogus USB workaround. (#131127)

* Mon Oct 18 2004 Dave Jones <davej@redhat.com>
- Rebase to 2.6.9
- Speedtouch USB DSL modem driver update.
- Cleanup some iseries config options.

* Fri Oct 15 2004 Dave Jones <davej@redhat.com>
- 2.6.9-rc4-bk3
- Fix up a bunch of unresolved symbols that crept in recently.
- Remove bogus O_NONBLOCK patch which broke lots of userspace.
- Fix booting on PPC64 by reserving initrd pages.

* Thu Oct 14 2004 Dave Jones <davej@redhat.com>
- Rebase to 2.6.9-rc4-bk2
- librtas needs to work around the /dev/mem restrictions.
- EXT3 reservations use-before-initialised bugfix.
- Merge Emulex LightPulse FC driver.
- support O_NONBLOCK for read,pread,readv of regular files.
- EDD blows up some x86-64's. Disable again.
- Resurrect the hugemem kernel for performance comparisons
  between 3G:1G and 4G:4G address space layouts.
  All non-hugemem kernels are now 3G userspace layout.

* Wed Oct 13 2004 Dave Jones <davej@redhat.com>
- Make EDD driver modular on x86-64 too.
- Various mkinitrd spec changes (Jeremy Katz)
- Enable a bunch more PPC64 config options. (Dave Howells)
- Enable ACPI cpufreq driver for x86-64 too.

* Tue Oct 12 2004 Dave Jones <davej@redhat.com>
- Rebase to 2.6.9-rc4-bk1
- Tux update.
- Update netdump/diskdump patches
- PowerPC 64 netboot changes.
- Various CONFIG_ option diddling.
- Fix up the find_isa_irq_pin() oops on reboot for x86-64 too. 

* Mon Oct 11 2004 Dave Jones <davej@redhat.com>
- Rebase to 2.6.9-rc4
- Enable CONFIG_MICROCODE for x86-64

* Fri Oct  8 2004 Dave Jones <davej@redhat.com>
- Rebase to 2.6.9-rc3-bk8

* Thu Oct  7 2004 Dave Jones <davej@redhat.com>
- Rebase to 2.6.9-rc3-bk7
- Fix up PPC/PPC64 compilation failures due to new binutils. (David Woodhouse)

* Wed Oct  6 2004 Dave Jones <davej@redhat.com>
- Rebase to 2.6.9-rc3-bk6
- Add xattr support for tmpfs.

* Mon Oct  4 2004 Stephen C. Tweedie <sct@redhat.com>
- Update ext3 online resize to 2.6.9-rc3-mm2 upstream
- Reenable ext3 online resize in .spec

* Tue Sep 28 2004 Jeremy Katz <katzj@redhat.com>
- add patch from Roland McGrath/James Morris to fix mprotect hook bug (#133505)

* Mon Sep 20 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.9-rc2-bk5

* Thu Sep 16 2004 Arjan van de Ven <arjanv@redhat.com>
- fix tux for x86-64 and ppc64

* Tue Sep 14 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.9-rc2
- add diskdump

* Fri Sep 10 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.9-rc1-bk17 ; make ppc32 build

* Tue Sep 07 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.9-rc1-bk13

* Mon Sep 06 2004 Arjan van de Ven <arjanv@redhat.com>
- disable online resize again
- hopefully fix Quake3 interaction with execshield
- add Alan's borken-bios-IRQ workaround patch

* Sat Sep 04 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.9-rc1-bk11

* Tue Aug 31 2004 Arjan van de Ven <arjanv@redhat.com>
- fix execshield buglet with legacy binaries
- 2.6.9-rc1-bk7

* Mon Aug 30 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.9-rc1-bk6

* Sat Aug 28 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.9-rc1-bk4, now with i915 DRM driver

* Fri Aug 27 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.9-rc1-bk2 

* Mon Aug 23 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.8.1-bk2

* Sat Aug 21 2004 Arjan van de Ven <arjanv@redhat.com>
- attempt to fix early-udev bug

* Fri Aug 13 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.8-rc4-bk3
- split execshield up some more

* Fri Aug 13 2004 Dave Jones <davej@redhat.com>
- Update SCSI whitelist again with some more card readers.

* Mon Aug 9 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.8-rc3-bk3

* Wed Aug 4 2004 Arjan van de Ven <arjanv@redhat.com>
- Add the flex-mmap bits for s390/s390x (Pete Zaitcev)
- Add flex-mmap for x86-64 32 bit emulation
- 2.6.8-rc3

* Mon Aug 2 2004 Arjan van de Ven <arjanv@redhat.com>
- Add Rik's token trashing control patch

* Sun Aug 1 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.8-rc2-bk11

* Fri Jul 30 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.8-rc2-bk8

* Wed Jul 28 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.8-rc2-bk6
- make a start at splitting up the execshield patchkit

* Fri Jul 16 2004 Arjan van de Ven <arjanv@redhat.com>
- ppc32 embedded updates

* Thu Jul 15 2004 Arjan van de Ven <arjanv@redhat.com>
- make USB modules again and add Alan's real fix for the SMM-meets-USB bug
- 2.6.8-rc1-bk4

* Wed Jul 14 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.8-rc1-bk3

* Tue Jul 13 2004 Arjan van de Ven <arjanv@redhat.com>
- add "enforcemodulesig" boot option to make the kernel load signed modules only

* Mon Jul 12 2004 Arjan van de Ven <arjanv@redhat.com>
- updated voluntary preempt
- 2.6.8-rc1

* Wed Jul 7 2004 Arjan van de Ven <arjanv@redhat.com>
- fix boot breakage that was hitting lots of people (Dave Jones)

* Tue Jul 6 2004 Arjan van de Ven <arjanv@redhat.com>
- add voluntary preemption patch from Ingo
- 2.6.7-bk19

* Tue Jun 29 2004 Arjan van de Ven <arjanv@redhat.com>
- make a start at gpg signed modules support

* Sat Jun 27 2004 Arjan van de Ven <arjanv@redhat.com>
- experiment with making the hardlink call in post more efficient
- 2.6.7-bk9

* Thu Jun 24 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.7-bk7
- Add wli's patch to allocate memory bottom up not top down
- change some config options in the kernel-sourcecode package that are
  good for rpm kernel builds but not for custom user builds to more appropriate 
  default values.
- reenable kernel-sourcecode again for a few builds 

* Wed Jun 23 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.7-bk5
- fix tux unresolved symbols (#126532)

* Mon Jun 21 2004 Arjan van de Ven <arjanv@redhat.com>
- make kernel-doc and kernel-sourcecode builds independent of eachother
- disable kernel-sourcecode builds entirely, we'll be replacing it with documentation
  on how to use the src.rpm instead for building your own kernel.

* Sat Jun 19 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.7-bk2

* Sun Jun 13 2004 Arjan van de Ven <arjanv@redhat.com>
- add patch from DaveM to fix the ppp-keeps-iface-busy bug

* Sat Jun 12 2004 Arjan van de Ven <arjanv@redhat.com>
- add fix from Andi Kleen/Linus for the fpu-DoS

* Thu Jun 10 2004 Arjan van de Ven <arjanv@redhat.com>
- disable mlock-uses-rlimit patch, it has a security hole and needs more thought
- revert airo driver to the FC2 one since the new one breaks

* Tue Jun 8 2004 Dave Jones <davej@redhat.com>
- Update to 2.6.7rc3

* Fri Jun 4 2004 Arjan van de Ven <arjanv@redhat.com>
- fix the mlock-uses-rlimit patch

* Wed Jun 2 2004 David Woodhouse <dwmw2@redhat.com>
- Add ppc64 (Mac G5)

* Wed Jun 2 2004 Arjan van de Ven <arjanv@redhat.com>
- add a forward port of the mlock-uses-rlimit patch
- add NX support for x86 (Intel, Ingo)

* Tue Jun 1 2004 Arjan van de Ven <arjanv@redhat.com>
- refresh ext3 reservation patch

* Sun May 30 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.7-rc2
- set the ACPI OS name to "Microsoft Windows XP" for better compatibility

* Thu May 27 2004 Pete Zaitcev <zaitcev@redhat.com>
- Fix qeth and zfcp (s390 drivers): align qib by 256, embedded into qdio_irq.

* Thu May 27 2004 Dave Jones <davej@redhat.com>
- Fix the crashes on boot on Asus P4P800 boards. (#121819)

* Wed May 26 2004 Dave Jones <davej@redhat.com>
- Lots more updates to the SCSI whitelist for various
  USB card readers. (#112778, among others..)

* Wed May 26 2004 Arjan van de Ven <arjanv@redhat.com>
- back out ehci suspend/resume patch, it breaks
- add fix for 3c59x-meets-kudzu bug from Alan

* Tue May 25 2004 Arjan van de Ven <arjanv@redhat.com>
- try improving suspend/resume by restoring more PCI state
- 2.6.7-rc1-bk1

* Mon May 24 2004 Dave Jones <davej@redhat.com>
- Add yet another multi-card reader to the whitelist (#85851)

* Sun May 23 2004 Dave Jones <davej@redhat.com>
- Add another multi-card reader to the whitelist (#124048)

* Wed May 19 2004 Arjan van de Ven <arjanv@redhat.com>
- put firewire race fix in (datacorruptor)

* Tue May 18 2004 Dave Jones <davej@redhat.com>
- Fix typo in ibmtr driver preventing compile (#123391)

* Mon May 17 2004 Arjan van de Ven <arjanv@redhat.com>
- update to 2.6.6-bk3
- made kernel-source and kernel-doc noarch.rpm's since they are not
  architecture specific.

* Sat May 08 2004 Arjan van de Ven <arjanv@redhat.com>
- fix non-booting on Transmeta cpus (Peter Anvin)
- fix count leak in message queues

* Fri May 07 2004 Arjan van de Ven <arjanv@redhat.com>
- more ide cache flush work
- patch from scsi-bk to fix sd refcounting

* Thu May 06 2004 Arjan van de Ven <arjanv@redhat.com>
- some more ide cache flush fixes 

* Wed May 05 2004 Arjan van de Ven <arjanv@redhat.com>
- fix bug 122504
- convert b44 to ethtool ops (jgarzik)
- make IDE do a cache-flush on shutdown (me/Alan)

* Tue May 04 2004 Arjan van de Ven <arjanv@redhat.com>
- work around i810/i830 DRM issue

* Fri Apr 30 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.6-rc3-bk1
- make amd64 boot again
- fix vm86-vs-4g4g interaction (Ingo)

* Thu Apr 22 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.6-rc2
 
* Tue Apr 20 2004 Arjan van de Ven <arjanv@redhat.com>
- add the ext3 online resize patch

* Mon Apr 19 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.6-rc1-bk3
- add the objrmap vm from the -mm tree; it needs testing

* Thu Apr 15 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.5-bk2
- disable DISCONTIGMEM on ia64 for performance
- fix sleep_on use in reiserfs (Chris Mason)

* Tue Apr 13 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.5-mc4
- reenable sg driver for scsi tape changers and such
- the sk98lin driver oopses on module unload, preven that

* Mon Apr 12 2004 Arjan van de Ven <arjanv@redhat.com>
- fix "bad pmd" bug with patch from Ingo

* Fri Apr 09 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.5-mc3
- finish up the -mc2 merge
- latest 4g/4g patch from Ingo
- latest execshield patch from Ingo
- fix a few framebuffer bugs

* Thu Apr 08 2004 Arjan van de Ven <arjanv@redhat.com>
- first attempt at a 2.6.5-mc2 merge

* Thu Apr 08 2004 Dave Jones <davej@redhat.com>
- Add in missing SiS AGP fix.

* Tue Apr 06 2004 Dave Jones <davej@redhat.com>
- More agpgart fixes.

* Fri Apr 02 2004 Arjan van de Ven <arjanv@redhat.com>
- fix another 4g/4g-vs-resume bug

* Tue Mar 30 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.5-rc3
- fix PCI posting bug in i830 DRM

* Mon Mar 29 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.5-rc2-bk8

* Mon Mar 29 2004 Dave Jones <davej@redhat.com>
- Include latest agpgart fixes.

* Thu Mar 25 2004 Arjan van de Ven <arjanv@redhat.com>
- more DRM fixes
- add the fsync patches from akpm

* Tue Mar 23 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.5-rc2-bk3
- fix direct userspace memory access in i830 drm driver

* Mon Mar 22 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.5-rc2-bk2
- some stackbloat reductions from Dave and me

* Sat Mar 20 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.5-rc2

* Tue Mar 16 2004 Dave Jones <davej@redhat.com>
- 2.6.5-rc1

* Mon Mar 15 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.4-bk3
- fix oops in toshiba_acpi (Barry K. Nathan)

* Sat Mar 13 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.4-bk2 merge 

* Thu Mar 11 2004 Arjan van de Ven <arjanv@redhat.com>
- renable sonypi driver that was off accidentally
- 2.6.4-final 
- fix the oops on alsa module unloads

* Wed Mar 10 2004 Arjan van de Ven <arjanv@redhat.com>
- add ppc64/iseries, ppc32 (powermac/ibook) and ia64 architectures
- 2.6.4-rc3 

* Tue Mar 09 2004 Arjan van de Ven <arjanv@redhat.com>
- 2.6.4-rc2-bk5
- fix nfs-vs-selinux issue
- fix typo in URL as per #117849

* Mon Mar 08 2004 Arjan van de Ven <arjanv@redhat.com>
- fix race in lp.c (#117710)
- 2.6.4-rc2-bk3
- attempt to fix S3 suspend-to-ram with 4g/4g split

* Sat Mar 06 2004 Arjan van de Ven <arjanv@redhat.com>
- fix reiserfs
- set HZ to 1000 again for some tests

* Wed Feb 25 2004 Arjan van de Ven <arjanv@redhat.com>
- merge back a bunch of fedora fixes
- disable audit

* Tue Feb 24 2004 Arjan van de Ven <arjanv@redhat.com>
- audit bugfixes
- update tux to a working version
- 2.6.3-bk5 merge

* Fri Feb 20 2004 Arjan van de Ven <arjanv@redhat.com>
- re-add and enable the Auditing patch
- switch several cpufreq modules to built in since detecting in userspace
  which to use is unpleasant
* Thu Jul 03 2003 Arjan van de Ven <arjanv@redhat.com>
- 2.6 start 
